//------------------------------
//AI Inventory functions

// debug flags are in aiObjectives.cs - pinkpanther

function AINeedEquipment(%equipmentList, %client)
{
   %index = 0;
   %item = getWord(%equipmentList, %index);

if ($debugInv) echo (getTaggedString(%client.name) @ " AINeedEquipment:eq.List:"@%equipmentList@" item:"@%item@" #inv:"@%client.player.getInventory(%item));
   //first, see if we're testing the armor class as well...
   if (%item $= "Heavy" || %item $= "Medium" || %item $= "Light" || %item $= "FieldTech" || %item $= "Sniper" || %item $= "Recon" || %item $= "Titan")       // Triumph armors added 7/13/04 pinkpanther@swissonline.ch
   {
      if (%client.player.getArmorSize() !$= %item)
         return true;

      %index++;
      %item = getWord(%equipmentList, %index);
   }

   while (%item !$= "")
   {
      if (%client.player.getInventory(%item) == 0)
         return true;

      //get the next item
      %index++;
      %item = getWord(%equipmentList, %index);
   }

   //made it through the list without needing anything
   return false;
}

function AIBuyInventory(%client, %requiredEquipment, %equipmentSets, %buyInvTime)
{
   //make sure we have a live player
   %player = %client.player;
   if (!isObject(%player))
      return "Failed";

   if (! AIClientIsAlive(%client))
      return "Failed";

   //see if we've already initialized our state machine
   if (%client.buyInvTime == %buyInvTime)
      return AIProcessBuyInventory(%client);

   //if the closest inv station is not a remote, buy the first available set...
   %result = AIFindClosestInventory(%client, false);
   %closestInv = getWord(%result, 0);
   %closestDist = getWord(%result, 1);
   if (%closestInv <= 0)
      return "Failed";

   //see if the closest inv station was a remote
   %buyingSet = false;
   %usingRemote = false;
   if (%closestInv.getDataBlock().getName() $= "DeployedStationInventory")
   {
      //see if we can buy at least the required equipment from the set
      if (%requiredEquipment !$= "")
      {
         if (! AIMustUseRegularInvStation(%requiredEquipment, %client))
            %canUseRemote = true;
         else
            %canUseRemote = false;
      }
      else
      {
         %inventorySet = AIFindSameArmorEquipSet(%equipmentSets, %client);
         if (%inventorySet !$= "")
            %canUseRemote = true;
         else
            %canUseRemote = false;
      }

      //if we can't use a remote, we need to look for a regular inv station
      if (! %canUseRemote)
      {
         %result = AIFindClosestInventory(%client, true);
         %closestInv = getWord(%result, 0);
         %closestDist = getWord(%result, 1);
         if (%closestInv <= 0)
            return "Failed";
      }
      else
         %usingRemote = true;
   }

   //at this point we've found the closest inv, see which set/list we need to buy
   if (!%usingRemote)
   {
      //choose the equipment first equipment set
      if (%equipmentSets !$= "")
      {
         %inventorySet = getWord(%equipmentSets, 0);
         %buyingSet = true;
      }
      else
      {
         %inventorySet = %requiredEquipment;
         %buyingSet = false;
      }
   }
   else
   {
      %inventorySet = AIFindSameArmorEquipSet(%equipmentSets, %client);
      if (%inventorySet $= "")
      {
         %inventorySet = %requiredEquipment;
         %buyingSet = false;
      }
      else
         %buyingSet = true;
   }

   //init some vars for the state machine...
   %client.buyInvTime = %buyInvTime; //used to mark the begining of the inv buy session
   %client.invToUse = %closestInv;	//used if we need to go to an alternate inv station
   %client.invWaitTime = "";	//used to track how long we've been waiting
   %client.invBuyList = %inventorySet; //the list/set of items we're going to buy...
   %client.buyingSet = %buyingSet; //whether it's a list or a set...
   %client.isSeekingInv = false;
   %client.seekingInv = "";

   //now process the state machine
   return AIProcessBuyInventory(%client);
}

//--------------------------------------------------------------------------------------------------
//long needed fix for AI in Tribes 2 ---------------------------------------------- Lagg... 3-14-2003
//bots will never get stuck on a remote inventory again :)

function AIProcessBuyInventory(%client)
{
   //get some vars
   %player = %client.player;
   if (!isObject(%player))
      return "Failed";

   %closestInv = %client.invToUse;
   %inventorySet = %client.invBuyList;
   %buyingSet = %client.buyingSet;

   //make sure it's still valid, enabled, and on our team
   if (! (%closestInv > 0 && isObject(%closestInv) && (%closestInv.team <= 0 || %closestInv.team == %client.team) && %closestInv.isEnabled()))
   {
      //reset the state machine
      %client.buyInvTime = 0;
      //return "InProgress";
      //echo("RETURN FAILED ! - LAGG...");
      return "Failed";
   }

   //use the Y-axis of the rotation as the desired direction of approach,
   //and calculate a walk to point 1.1 - 1.3 m behind the trigger point - Lagg...
   %aprchDirection = MatrixMulVector("0 0 0 " @ getWords(%closestInv.getTransform(), 3, 6), "0 1 0");
   %aprchDirection = VectorNormalize(%aprchDirection);

   //make sure the inventory station is not blocked
   %invLocation = %closestInv.getWorldBoxCenter();
   InitContainerRadiusSearch(%invLocation, 2, $TypeMasks::PlayerObjectType);
   %objSrch = containerSearchNext();
   if (%objSrch == %client.player)
      %objSrch = containerSearchNext();

   //the closestInv is busy...
   if (%objSrch > 0)
   {
      //have the AI range the inv
      if (%client.seekingInv $= "" || %client.seekingInv != %closestInv)
      {
         %client.invWaitTime = "";
         %client.seekingInv = %closestInv;
         %client.stepRangeObject(%closestInv, "DefaultRepairBeam", 5, 10);
      }
      //inv is still busy - see if we're within range
      else if (%client.getStepStatus() $= "Finished")
      {
         //initialize the wait time
         if (%client.invWaitTime $= "")
            %client.invWaitTime = getSimTime() + 5000 + (getRandom() * 10000);
         //else see if we've waited long enough
         else if (getSimTime() > %client.invWaitTime)
         {
            schedule(250, %client, "AIPlayAnimSound", %client, %objSrch.getWorldBoxCenter(), "vqk.move", -1, -1, 0);
            %client.invWaitTime = getSimTime() + 5000 + (getRandom() * 10000);
         }
      }
      else
      {
         //in case we got bumped, and are ranging the target again...
         %client.invWaitTime = "";
      }
   }
   //else if we've triggered the inv, automatically give us the equipment...
   else if (isObject(%closestInv) && isObject(%closestInv.trigger) && VectorDist(%closestInv.trigger.getWorldBoxCenter(), %player.getWorldBoxCenter()) < 1.5)
   {
      //first stop...
      %client.stop();
      %index = 0;
      if (%buyingSet)
      {
         //first, clear the players inventory
         %player.clearInventory();
         %item = $AIEquipmentSet[%inventorySet, %index];
      }
      else
         %item = getWord(%inventorySet, %index);


      //armor must always be bought first
	if (%item $= "Light" || %item $= "Medium" || %item $= "Heavy" || %item $= "FieldTech" || %item $= "Sniper" || %item $= "Recon" || %item $= "Titan")       // Triumph armors added 7/13/04 pinkpanther@swissonline.ch
	{
	   %player.setArmor(%item);
	   %index++;
	}

      //set the data block after the armor had been upgraded
      %playerDataBlock = %player.getDataBlock();

      //next, loop through the inventory set, and buy each item
      if (%buyingSet)
         %item = $AIEquipmentSet[%inventorySet, %index];
      else
         %item = getWord(%inventorySet, %index);

      while (%item !$= "")
      {
         //set the inventory amount to the maximum quantity available
         if (%player.getInventory(AmmoPack) > 0)
            %ammoPackQuantity = AmmoPack.max[%item];
         else
            %ammoPackQuantity = 0;

         %quantity = %player.getDataBlock().max[%item] + %ammoPackQuantity;
         if ($InvBanList[$CurrentMissionType, %item])
            %quantity = 0;

         // ZOD 2-2-03: Added Force = 1, make sure they get their stuff, I hope.
         %player.setInventory(%item, %quantity, 1);

         //get the next item
         %index++;
         if (%buyingSet)
            %item = $AIEquipmentSet[%inventorySet, %index];
         else
            %item = getWord(%inventorySet, %index);
      }

      //put a weapon in the bot's hand...
      %player.cycleWeapon();

      //return a success - but wait if we are not healed all the way :) - Lagg...
      //if (%player.getDamagePercent() <= 0)
      //{
         //get away from inventory if we are done - Lagg...
         %client.setDangerLocation(%invLocation, 15);
         return "Finished";
      //}
   }
   //else, keep moving towards the inv station
   else
   {
      if (isObject(%closestInv) && isObject(%closestInv.trigger))
      {
         //quite possibly we may need to deal with what happens if a bot doesn't have a path to the inv...
         //the current premise is that no inventory stations are "unpathable"...
         //this is true so I have fixed it some what - Lagg... :)

         //if (%client.isSeekingInv)
         //{
         //   %dist = %client.getPathDistance(%closestInv.trigger.getWorldBoxCenter());
         // if (%dist < 0)
         //	error("DEBUG Tinman - still need to handle bot stuck trying to get to an inv!");
         //}
         //calculate the approachFromLocation
         if (%closestInv.getDataBlock().getName() $= "MobileInvStation")
            %factor = -2;
         else
         {
            %clientArmor = %client.player.getArmorSize();
            if (%clientArmor $= "Heavy" || %clientArmor $= "Titan")       // Triumph armors added 7/13/04 pinkpanther@swissonline.ch
	         %factor = -1.3;//1.3m behind inv trigger for heavy bots
            else if (%clientArmor $= "Medium" || %clientArmor $= "FieldTech")       // Triumph armors added 7/13/04 pinkpanther@swissonline.ch
	         %factor = -1.175;//1.175m behind inv trigger for medium bots
            else
               %factor = -1.1;//1.1m behind inv trigger for light bots
         }
         %aprchFromLocation = VectorAdd(%invLocation,VectorScale(%aprchDirection, %factor));
         %client.stepMove(%aprchFromLocation);
         %client.isSeekingInv = true;
      }
      //added here so bots shoot - Lagg... 9-18-2003
      //this call works in conjunction with AIEngageTask
	%client.setEngageTarget(%client.shouldEngage);

      return "InProgress";
   }
}

function AIFindSameArmorEquipSet(%equipmentSets, %client)
{
   %clientArmor = %client.player.getArmorSize();
   %index = 0;
   %set = getWord(%equipmentSets, %index);
   while (%set !$= "")
   {
      if ($AIEquipmentSet[%set, 0] $= %clientArmor)
         return %set;

      //get the next equipment set in the list of sets
      %index++;
      %set = getWord(%equipmentSets, %index);
   }
   return "";
}

//---------------------------------------------------------------------------------------------------

//killed a couple roaches here :) - Lagg... - 4-12-2003
function AIMustUseRegularInvStation(%equipmentList, %client)
{
   %clientArmor = %client.player.getArmorSize();
   %clientDb = getArmorDatablock(%client, %clientArmor); // ZOD: Get our datablock

   //first, see if the set contains an item not available
   %index = 0;
   %item = getWord(%equipmentList, 0);
   while (%item !$= "")
   {
      //error("AIMustUseRegularInvStation( " @ %item @ ", " @ %client.nameBase @ " )");
      // ZOD: Does the set include armor and if so do we allready have it?
      if((%item $= "Light" || %item $= "Medium" || %item $= "Heavy" || %item $= "FieldTech" || %item $= "Sniper" || %item $= "Recon" || %item $= "Titan") && (%clientArmor !$= %item))       // Triumph armors added 7/13/04 pinkpanther@swissonline.ch
      {
         return true;
      }
      // ZOD: Does the set include items we can't carry in our current armor?
      else if((%clientDb.max[%item] <= 0) || (%item $= "InventoryDeployable"))
      {
         return true;
      }
      // ZOD: There are items in the set we can get from a remote and can carry in current armor..
      else
      {
         %index++;
	   %item = getWord(%equipmentList, %index);
      }
   }

   //otherwise, see if the set begins with an armor class
   %needArmor = %equipmentList[0];
   if (%needArmor !$= "Light" && %needArmor !$= "Medium" && %needArmor !$= "Heavy" || %needArmor $= "FieldTech" || %needArmor $= "Sniper" || %needArmor $= "Recon" || %needArmor $= "Titan")       // Triumph armors added 7/13/04 pinkpanther@swissonline.ch
      return false;

   //also including looking for an inventory set
   //this one does not seem to work light armor still bought at remotes(fixed above) - Lagg...
   if (%needArmor != %clientArmor)
      return true;

   //we must be fine...
   return false;
}

//---------------------------------------------------------------------------------------------------------------
//is called from - 'AIPickupItemTask' in "aiDefaultTasks.cs"
//makes calls to - 'function AICanPickupWeapon'

//modified for better performance and bugs removed - Lagg... 4-3-2003 - (updated 11-5-2003)
function AICouldUseItem(%client, %item)
{
   if(!AIClientIsAlive(%client))
      return false;

   %player = %client.player;
   if (!isObject(%player))
      return false;

   %playerDataBlock = %client.player.getDataBlock();
   %armor = %player.getArmorSize();
   %type = %item.getDataBlock().getName();

   //check packs first
   if(%item.getDataBlock().className $= Pack)
   {
      if(%playerDataBlock.max[%type] > 0)
      {
         if(%player.getMountedImage($BackpackSlot) <= 0)
            return true;
         else
            return false;
      }
   }

   //if the item is acutally, a corpse, check the corpse inventory and compare it to ours - Lagg...
   // ZOD: Ammo only apparently
   if (%item.isCorpse)
   {
      for(%j = 0; $ammoType[%j] !$= ""; %j++)
      {
         if (%item.getInventory($ammoType[%j]) > 0)
         {
            if(%player.getInventory($ammoType[%j]) < %playerDataBlock.max[$ammoType[%j]])
               return true;
         }
      }
   }
   else
   {
      //check ammo
      if(%item.getDataBlock().className $= Ammo)
      {
         %quantity = mFloor(%playerDataBlock.max[%type]);
         if (%player.getInventory(%type) < %quantity)
            return true;
      }
      else if(%item.getDataBlock().className $= HandInventory)
      {
         // ZOD: Loop through grenades and see what type of grenade we allready carry..
         for(%i = 0; $InvGrenade[%i] !$= ""; %i++)
         {
            %gren = $NameToInv[$InvGrenade[%x]];
            if (%player.getInventory(%gren) > 0 && %gren $= %type) // We have this grenade
            {
               %quantity = mFloor(%playerDataBlock.max[%type]); // How many can we carry?
               if (%player.getInventory(%type) < %quantity) // Ok we have less then the total we can carry
                  return true;
            }
         }
      }

      //see if we can carry another weapon...
      if (AICanPickupWeapon(%client, %item))
         return true;
   }
   //guess we didn't find anything useful...  (should still check for mines and grenades) did that - Lagg...
   return false;
}

//-----------------------------------------------------------------------------------------------------------

//added check for all weapons - Lagg... - 4-12-2003
function AIEngageOutofAmmo(%client)
{
   //this function only cares about weapons used in engagement...
   //no mortars, or missiles - yeah right...Lagg
   %player = %client.player;
   if (!isObject(%player))
      return false;

   %ammoWeapons = 0;
   %energyWeapons = 0;

   //get our inventory
   %hasBlaster = (%player.getInventory("Blaster") > 0);
   %hasPlasma  = (%player.getInventory("Plasma") > 0);
   %hasChain   = (%player.getInventory("Chaingun") > 0);
   %hasDisc    = (%player.getInventory("Disc") > 0);
   %hasGrenade = (%player.getInventory("GrenadeLauncher") > 0);
   %hasSniper  = (%player.getInventory("SniperRifle") > 0) && (%player.getInventory("EnergyPack") > 0);
   %hasELF     = (%player.getInventory("ELFGun") > 0);
   %hasMortar  = (%player.getInventory("Mortar") > 0);
   %hasMissile = (%player.getInventory("MissileLauncher") > 0);
   %hasLance   = (%player.getInventory("ShockLance") > 0);
   // ----- Triumph specific weapons here: pinkpanther 07/21/04  -----
   %hasAntiAirGun    = (%player.getInventory("AntiAirGun") > 0);
   %hasBeamSword     = (%player.getInventory("BeamSword") > 0);
   %hasDualBlaster   = (%player.getInventory("DualBlaster") > 0);
   %hasElfCannon     = (%player.getInventory("ElfCannon") > 0);
   %hasGatlingGun    = (%player.getInventory("GatlingGun") > 0);
   %hasHeadHunter    = (%player.getInventory("HeadHunter") > 0) && (%player.getInventory("EnergyPack") > 0);
   %hasHeavyLauncher = (%player.getInventory("HeavyLauncher") > 0);
   %hasHornet        = (%player.getInventory("Hornet") > 0);
   %hasNapalm        = (%player.getInventory("Napalm") > 0);
   %hasRailNade      = (%player.getInventory("RailNade") > 0);
   %hasShotgun       = (%player.getInventory("Shotgun") > 0);
   %hasSlugRifle     = (%player.getInventory("SlugRifle") > 0);
   %hasSolarCharge   = (%player.getInventory("SolarCharge") > 0);
   %hasTitanChaingun = (%player.getInventory("TitanChaingun") > 0);

   if (%hasBlaster || %hasSniper || %hasElf || %hasLance || %hasHeadHunter || %hasDualBlaster || %hasSolarCharge || %hasElfCannon || %hasNapalm || %hasBeamSword)	// pinkpanther 07/21/04
      return false;
   else
   {
      // we only have ammo type weapons
      if(%hasDisc && (%player.getInventory("DiscAmmo") > 0))
         return false;
      else if(%hasChain && (%player.getInventory("ChainGunAmmo") > 0))
         return false;
      else if(%hasGrenade && (%player.getInventory("GrenadeLauncherAmmo") > 0))
         return false;
      else if(%hasPlasma && (%player.getInventory("PlasmaAmmo") > 0))
         return false;
      else if(%hasMissile && (%player.getInventory("MissileLauncherAmmo") > 0))
         return false;
      else if(%hasMortar && (%player.getInventory("MortarAmmo") > 0))
         return false;
   // ----- Triumph specific weapons here: pinkpanther 07/21/04  -----
      else if(%hasAntiAirGun && (%player.getInventory("AntiAirGunAmmo") > 0))
         return false;
      else if(%hasGatlingGun && (%player.getInventory("GatlingGunAmmo") > 0))
         return false;
      else if(%hasHeavyLauncher && (%player.getInventory("HeavyLauncherAmmo") > 0))
         return false;
      else if(%hasHornet && (%player.getInventory("HornetAmmo") > 0))
         return false;
      else if(%hasRailNade && (%player.getInventory("RailNadeAmmo") > 0))
         return false;
      else if(%hasShotgun && (%player.getInventory("ShotgunAmmo") > 0))
         return false;
      else if(%hasSlugRifle && (%player.getInventory("SlugRifleAmmo") > 0))
         return false;
      else if(%hasTitanChaingun && (%player.getInventory("TitanChaingunAmmo") > 0))
         return false;
   }
   return true; // were out!
}

//------------------------------------------------------------------------------------------------
//is called from - 'function AICouldUseItem'
//makes calls to - ''


//almost a complete rewrite here :) - Lagg... 11-5-2003
function AICanPickupWeapon(%client, %weapon)
{
   //first, make sure it's not a weapon we already have...
   %player = %client.player;
   if (!isObject(%player))
      return false;

   %armor = %player.getArmorSize();
   if (%player.getInventory(%weapon) > 0)
      return false;

   %type = %weapon.getDataBlock().getName();
   %aBlock = %player.getDatablock(); // ZOD: Get our datablock

   // ZOD: Loop through the weapon arrays, less lines this way.
   %weaponCount = 0;
   for(%a = 0; $InvWeapon[%a] !$= ""; %a++)
   {
      if(%player.getInventory($NameToInv[$InvWeapon[%a]]) > 0)
         %weaponCount++;
   }

   // ZOD: Now check to see if we can carry the item
   if(%weaponCount < %aBlock.maxWeapons)
   {
      // ZOD: We have a special case for the sniper rifle only..
      if(%type $= "SniperRifle" && %player.getInventory("EnergyPack") >= 0)
         return true;
      else if(%aBlock.max[%type] > 0)
         return true;
      else
         return false;
   }
}

//-----------------------------------------------------------------------------------------------------------

//added for use of all weapons - Lagg... 4-12-2003
function AIEngageWeaponRating(%client)
{
   %player = %client.player;
   if (!isObject(%player))
      return;

   %playerDataBlock = %client.player.getDataBlock();

   //get our inventory
   %hasBlaster = (%player.getInventory("Blaster") > 0);
   %hasPlasma  = (%player.getInventory("Plasma") > 0 && %player.getInventory("PlasmaAmmo") >= 1);
   %hasMortar  = (%player.getInventory("Mortar") > 0 && %player.getInventory("MortarAmmo") >= 1);
   %hasChain   = (%player.getInventory("Chaingun") > 0 && %player.getInventory("ChaingunAmmo") >= 1);
   %hasDisc    = (%player.getInventory("Disc") > 0 && %player.getInventory("DiscAmmo") >= 1);
   %hasGrenade = (%player.getInventory("GrenadeLauncher") > 0 && %player.getInventory("GrenadeLauncherAmmo") >= 1);
   %hasMissile = (%player.getInventory("MissileLauncher") > 0 && %player.getInventory("MissileLauncherAmmo") >= 1);
   %hasSniper  = (%player.getInventory("SniperRifle") > 0) && (%player.getInventory("EnergyPack") > 0);
   %hasELF     = (%player.getInventory("ELFGun") > 0);
   %hasLance   = (%player.getInventory("ShockLance") > 0);
   // ----- Triumph specific weapons here: pinkpanther 07/21/04  -----
   %hasAntiAirGun    = (%player.getInventory("AntiAirGun") > 0) && %player.getInventory("AntiAirGunAmmo") > 0;
   %hasBeamSword     = (%player.getInventory("BeamSword") > 0);
   %hasDualBlaster   = (%player.getInventory("DualBlaster") > 0);
   %hasElfCannon     = (%player.getInventory("ElfCannon") > 0);
   %hasGatlingGun    = (%player.getInventory("GatlingGun") > 0 && %player.getInventory("GatlingGunAmmo") > 0);
   %hasHeadHunter    = (%player.getInventory("HeadHunter") > 0) && (%player.getInventory("EnergyPack") > 0);
   %hasHeavyLauncher = (%player.getInventory("HeavyLauncher") > 0 && %player.getInventory("HeavyLauncherAmmo") > 0);
   %hasHornet        = (%player.getInventory("Hornet") > 0 && %player.getInventory("HornetAmmo") > 0);
   %hasNapalm        = (%player.getInventory("Napalm") > 0);
   %hasRailNade      = (%player.getInventory("RailNade") > 0 && %player.getInventory("RailNadeAmmo") > 0);
   %hasShotgun       = (%player.getInventory("Shotgun") > 0 && %player.getInventory("ShotgunAmmo") > 0);
   %hasSlugRifle     = (%player.getInventory("SlugRifle") > 0 && %player.getInventory("SlugRifleAmmo") > 0);
   %hasSolarCharge   = (%player.getInventory("SolarCharge") > 0);
   %hasTitanChaingun = (%player.getInventory("TitanChaingun") > 0 && %player.getInventory("TitanChaingunAmmo") > 0);

   //check ammo
   %quantity = mFloor(%playerDataBlock.max[%type] * 0.7);

   %rating = 0;
   if (%hasBeamSword)
      %rating += 9;
   if (%hasBlaster)
      %rating += 9;
   if (%hasDualBlaster)
      %rating += 9;   // DualBlaster is the ONLY weapon of a recon!
   if (%hasSniper)
      %rating += 9;
   if (%hasHeadHunter)
      %rating += 9;
   if (%hasElf)
      %rating += 9;
   if (%hasElfCannon)
      %rating += 9;
   if (%hasLance)
      %rating += 9;
   if (%hasSlugRifle)
      %rating += 9;
   if (%hasNapalm)
      %rating += 9;

   if (%hasDisc)
   {
      %quantity = %player.getInventory("DiscAmmo") / %playerDataBlock.max["DiscAmmo"];
      %rating += 15 + (15 * %quantity);
   }
   if (%hasPlasma)
   {
      %quantity = %player.getInventory("PlasmaAmmo") / %playerDataBlock.max["PlasmaAmmo"];
      %rating += 15 + (15 * %quantity);
   }
   if (%hasShotgun)
   {
      %quantity = %player.getInventory("ShotgunAmmo") / %playerDataBlock.max["ShotgunAmmo"];
      %rating += 15 + (15 * %quantity);
   }
   if (%hasRailNade)
   {
      %quantity = %player.getInventory("RailNadeAmmo") / %playerDataBlock.max["RailNadeAmmo"];
      %rating += 15 + (15 * %quantity);
   }
   if (%hasChain)
   {
      %quantity = %player.getInventory("ChainGunAmmo") / %playerDataBlock.max["ChainGunAmmo"];
      %rating += 15 + (15 * %quantity);
   }
   if (%hasGatlingGun)
   {
      %quantity = %player.getInventory("GatlingGunAmmo") / %playerDataBlock.max["GatlingGunAmmo"];
      %rating += 15 + (15 * %quantity);
   }
   if (%hasTitanChaingun)
   {
      %quantity = %player.getInventory("TitanChaingunAmmo") / %playerDataBlock.max["TitanChaingunAmmo"];
      %rating += 15 + (15 * %quantity);
   }
   if (%hasHornet)
   {
      %quantity = %player.getInventory("HornetAmmo") / %playerDataBlock.max["HornetAmmo"];
      %rating += 15 + (15 * %quantity);
   }

   //not really an effective weapon for hand to hand...
   //if (%hasGrenade)
   //{
   //%quantity =  %player.getInventory("GrenadeLauncherAmmo") / %playerDataBlock.max["GrenadeLauncherAmmo"];
   //%rating += 10 + (15 * %quantity);
   //}
   //not really an effective weapon for hand to hand...
   // oh yes, and without weighing it, the AI gets in trouble spawning certain heavies - pinkpanther
   if (%hasMortar)
   {
   %quantity =  %player.getInventory("MortarAmmo") / %playerDataBlock.max["MortarAmmo"];
   %rating += 10 + (15 * %quantity);
   }
   //not really an effective weapon for hand to hand...
   //if (%hasMissile)
   //{
   //%quantity =  %player.getInventory("MissileLauncherAmmo") / %playerDataBlock.max["MissileLauncherAmmo"];
   //%rating += 10 + (15 * %quantity);
   //}

   //note a rating of 20+ means at least two energy weapons, or an ammo weapon with at least 1/3 ammo...
   return %rating;
}

function AIFindSafeItem(%client, %needType)
{
   %player = %client.player;
   if (!isObject(%player))
      return -1;

   %closestItem = -1;
   %closestDist = 32767;

   %itemCount = $AIItemSet.getCount();
   for (%i = 0; %i < %itemCount; %i++)
   {
      %item = $AIItemSet.getObject(%i);
      if (%item.isHidden())
         continue;

      %type = %item.getDataBlock().getName();
      if ((%needType $= "Health" && (%type $= "RepairKit" || %type $= "RepairPatch") && %player.getDamagePercent() > 0) ||
         (%needType $= "Ammo" && (%type $= "ChainGunAmmo" || %type $= "PlasmaAmmo" || %type $= "DiscAmmo" ||
          %type $= "GrenadeLauncherAmmo" || %type $= "MortarAmmo") && AICouldUseItem(%client, %item)) ||
         (%needType $= "Ammo" && AICanPickupWeapon(%type)) ||
         ((%needType $= "" || %needType $= "Any") && AICouldUseItem(%client, %item)))
      {
         //first, see if it's close to us...
         %distance = %client.getPathDistance(%item.getTransform());
         if (%distance > 0 && %distance < %closestDist)
         {
            //now see if it's got bad enemies near it...
            %clientCount = ClientGroup.getCount();
            for (%j = 0; %j < %clientCount; %j++)
            {
               %cl = ClientGroup.getObject(%j);
               if (%cl == %client || %cl.team == %client.team || !AIClientIsAlive(%cl))
                  continue;

               //if the enemy is stronger, see if they're close to the item
               if (AIEngageWhoWillWin(%client, %cl) == %cl)
               {
                  %tempDist = %client.getPathDistance(%item.getWorldBoxCenter());
                  if (%tempDist > 0 && %tempDist < %distance + 50)
                     continue;
               }
               //either no enemy, or a weaker one...
               %closestItem = %item;
               %closestDist = %distance;
            }
         }
      }
   }
   return %closestItem;
}

//-------------------------------------------

//big modifications here - Lagg... - 4-12-2003
function AIChooseObjectWeapon(%client, %targetObject, %distToTarg, %mode, %canUseEnergyStr, %environmentStr)
{
   //get our inventory
   %player = %client.player;
   if (!isObject(%player))
      return;

   if (!isObject(%targetObject))
      return;

   //check for LOS - Lagg..
   %mask = $TypeMasks::TerrainObjectType | $TypeMasks::InteriorObjectType |
           $TypeMasks::StaticTSObjectType | $TypeMasks::ForceFieldObjectType;
   %hasLOS = !containerRayCast(%player.getMuzzlePoint($WeaponSlot), %targetObject.getWorldBoxCenter(), %mask, 0);
   %playerVelocity = %player.getVelocity();

   %canUseEnergy = (%canUseEnergyStr $= "true");
   %inWater = (%environmentStr $= "water");
   %outdoors = (%environmentStr $= "outdoors");//added - Lagg... 1-20-2003
   %myEnergy = %player.getEnergyPercent();//added - Lagg... 1-28-2003
   %hasBlaster = (%player.getInventory("Blaster") > 0) && %canUseEnergy && %hasLOS; //pinkpanther - 07/22/04
   %hasPlasma = (%player.getInventory("Plasma") > 0) && (%player.getInventory("PlasmaAmmo") > 0) && !%inWater;
   %hasChain = (%player.getInventory("Chaingun") > 0) && (%player.getInventory("ChaingunAmmo") > 0);
   %hasDisc = (%player.getInventory("Disc") > 0) && (%player.getInventory("DiscAmmo") > 0);
   %hasGrenade = (%player.getInventory("GrenadeLauncher") > 0) && (%player.getInventory("GrenadeLauncherAmmo") > 0) && !%inWater;
   %hasSniper = (%player.getInventory("SniperRifle") > 0) && (%player.getInventory("EnergyPack") > 0) && %canUseEnergy && !%inWater;
   %hasMortar = (%player.getInventory("Mortar") > 0) && (%player.getInventory("MortarAmmo") > 0) && !%inWater;
   %hasRepairPack = (%player.getInventory("RepairPack") > 0) && %canUseEnergy;
   %hasTargetingLaser = (%player.getInventory("TargetingLaser") > 0) && %canUseEnergy && !%inWater;
   //added missile shocklance and elf ------------------------------------------------------------- Lagg... 1-15-2003
   %hasMissile = (%player.getInventory("MissileLauncher") > 0) && (%player.getInventory("MissileLauncherAmmo") > 0) && !%inWater;
   %hasShockLance = (%player.getInventory("ShockLance") > 0) && %canUseEnergy && !%inWater;
   %hasELF = (%player.getInventory("ELFGun") > 0) && %canUseEnergy && !%inWater;
   // ----- Triumph specific weapons here: pinkpanther 07/21/04  -----
   %hasAntiAirGun    = (%player.getInventory("AntiAirGun") > 0 && %player.getInventory("AntiAirGunAmmo") > 0) && !%inWater;
   %hasBeamSword     = (%player.getInventory("BeamSword") > 0 && (%distToTarg < 18) && %canUseEnergy && %hasLOS);
   %hasDualBlaster   = (%player.getInventory("DualBlaster") > 0 && %canUseEnergy && %hasLOS);
   %hasElfCannon     = (%player.getInventory("ElfCannon") > 0 && %canUseEnergy) && !%inWater;
   %hasGatlingGun    = (%player.getInventory("GatlingGun") > 0 && %player.getInventory("GatlingGunAmmo") > 0);
   %hasHeadHunter    = (%player.getInventory("HeadHunter") > 0) && (%player.getInventory("EnergyPack") > 0 && %canUseEnergy) && !%inWater;
   %hasHeavyLauncher = (%player.getInventory("HeavyLauncher") > 0 && %player.getInventory("HeavyLauncherAmmo") > 0) && !%inWater;
   %hasHornet        = (%player.getInventory("Hornet") > 0 && %player.getInventory("HornetAmmo") > 0) && (%playerVelocity < 1.0) && !%inWater && %hasLOS;
   %hasNapalm        = (%player.getInventory("Napalm") > 0 && %canUseEnergy) && !%inWater;
   %hasRailNade      = (%player.getInventory("RailNade") > 0 && %player.getInventory("RailNadeAmmo") > 0) && !%inWater;
   %hasShotgun       = (%player.getInventory("Shotgun") > 0 && %player.getInventory("ShotgunAmmo") > 0) && !%inWater;
   %hasSlugRifle     = (%player.getInventory("SlugRifle") > 0 && %player.getInventory("SlugRifleAmmo") > 0) && !%inWater && %hasLOS;
   %hasSolarCharge   = (%player.getInventory("SolarCharge") > 0 && %canUseEnergy) && (%playerVelocity < 1.0) && !%inWater && %outdoors && %hasLOS; // you better have LOS and are outdoors wth this ;-)
   %hasTitanChaingun = (%player.getInventory("TitanChaingun") > 0 && %player.getInventory("TitanChaingunAmmo") > 0);

   //choose the weapon
   %useWeapon = "NoAmmo";
   //see if we're destroying the object -- added for remote inventories destruction -------- Lagg...1-12-2003
   if (%mode $= "Destroy")
   {
      //heavy modifications here could not list em all ------------------------------ Lagg... 1-21-2003
      // same goes for my modifications ;-)    ------------------ pinkpanther - 07/22/04

      // ZOD: Compresed this a little bit
      if (%targetObject.getDataBlock().getClassName() $= "TurretData" ||
           %targetObject.getDataBlock().getName() $= "DeployedStationInventory" ||
           %targetObject.getDataBlock().getName() $= "DeployedMine")
      {
         if (%distToTarg < 20)
         {
            if (%hasNapalm)
               %useWeapon = "Napalm";
            else if (%BeamSword)
               %useWeapon = "BeamSword";
            else if (%hasPlasma)
               %useWeapon = "Plasma";
            else if (%hasChain)
               %useWeapon = "Chaingun";
            else if (%hasDualBlaster)
               %useWeapon = "DualBlaster";
            else if (%hasDisc)
               %useWeapon = "Disc";
         }
         else // ZOD: Is greater then 20 meters
         {
            if (%hasSolarCharge && (%myEnergy > 0.8))
               %useWeapon = "SolarCharge";
            else if (%hasDualBlaster)
               %useWeapon = "DualBlaster";
            else if (%hasBlaster)
               %useWeapon = "Blaster";
            else if (%hasMortar)
               %useWeapon = "Mortar";
            else if (%hasHornet)
               %useWeapon = "Hornet";
            else if (%hasDisc)
               %useWeapon = "Disc";
            else if (%hasRailNade)
               %useWeapon = "RailNade";
            else if (%hasPlasma && (%distToTarg < 50))
               %useWeapon = "Plasma";
         }
      }
      else if (%distToTarg < 20)
      {
         if (%hasNapalm)
            %useWeapon = "Napalm";
         else if (%hasBeamSword)
            %useWeapon = "BeamSword";
         else if (%hasDualBlaster)
            %useWeapon = "DualBlaster";
         else if (%hasPlasma)
            %useWeapon = "Plasma";
         else if (%hasChain)
            %useWeapon = "Chaingun";
         else if (%hasDisc)
            %useWeapon = "Disc";
         else if (%hasRailNade)
            %useWeapon = "RailNade";
         else if (%hasSniper && %myEnergy > 0.8)
            %useWeapon = "SniperRifle";
         else if (%hasBlaster)
            %useWeapon = "Blaster";
      }
   }
   //else See if we're repairing the object
   else if (%mode $= "Repair")
   {
      if (%hasRepairPack)
         %useWeapon = "RepairPack";
   }
   //else see if we're lazing the object
   else if (%mode $= "Laze")
   {
      // Here is the main hack in having the bots directly attack turrets & sensors. - pinkpanther 07/22/04
      // Instead of lazing I allow them to fire directly at the target as long as they got a appropriate weapon
      if (%BeamSword)
         %useWeapon = "BeamSword";
      else if (%hasDualBlaster && (%distToTarg < 250))
         %useWeapon = "DualBlaster";
      else if (%hasSolarCharge && (%myEnergy > 0.8))
         %useWeapon = "SolarCharge";
      else if (%hasHornet && (%distToTarg < 300) && (%myEnergy > 0.6 || !%hasSolarCharge))  // %myEnergy > 0.6 to prevent firing hornets while a slow solar charge is on its way to the target - pinkpanther 07/22/04
         %useWeapon = "Hornet";
      else if (%hasRailNade && (%distToTarg < 100) && (%myEnergy > 0.6 || !%hasSolarCharge))
         %useWeapon = "RailNade";
      else if (%hasTargetingLaser)
         %useWeapon = "TargetingLaser";
   }
   //else see if we're mortaring the object -- Made some modifications here -- Lagg... 1-12-2003
      // Same here as above: Before mortaring, we prefer the better stuff. - pinkpanther 07/22/04
   else if (%mode $= "Mortar")
   {
      if (%distToTarg < 25 && !%inWater)
      {
          if (%BeamSword)
            %useWeapon = "BeamSword";
          else if (%hasPlasma)
            %useWeapon = "Plasma";
          else if (%hasNapalm)
            %useWeapon = "Napalm";
          else if (%hasTitanChaingun)
            %useWeapon = "TitanChaingun";
          else if (%hasGatlingGun)
            %useWeapon = "GatlingGun";
          else if (%hasChain)
            %useWeapon = "Chaingun";
          else if (%hasHornet)
            %useWeapon = "Hornet";
          else if (%hasDisc)
            %useWeapon = "Disc";
          else if (%hasBlaster)
            %useWeapon = "Blaster";
      }
      else if (%distToTarg < 70 && !%inWater)
      {
          if (%hasSolarCharge && (%myEnergy > 0.8))
            %useWeapon = "SolarCharge";
          else if (%hasHornet && (%myEnergy > 0.6 || !%hasSolarCharge))  // %myEnergy > 0.6 to prevent firing hornets while a slow solar charge is on its way to the target - pinkpanther 07/22/04
            %useWeapon = "Hornet";
          else if (%hasMortar)
            %useWeapon = "Mortar";
          else if (%hasTitanChaingun)
            %useWeapon = "TitanChaingun";
          else if (%hasPlasma)
            %useWeapon = "Plasma";
          else if (%hasDisc)
            %useWeapon = "Disc";
          else if (%hasRailNade)
            %useWeapon = "RailNade";
          else if (%hasBlaster)
            %useWeapon = "Blaster";
      }
      else if (%distToTarg < 150 && %inWater)
      {
          if (%hasDualBlaster && %hasLOS)
            %useWeapon = "DualBlaster";
          else if (%hasTitanChaingun)
            %useWeapon = "TitanChaingun";
          else if (%hasGatlingGun)
            %useWeapon = "GatlingGun";
          else if (%hasDisc)
            %useWeapon = "Disc";
          else if (%hasChain)
            %useWeapon = "Chaingun";
          else if (%hasBlaster)
            %useWeapon = "Blaster";
      }
      else if (%distToTarg < 150 && !%inWater)
      {
          if (%hasSolarCharge && (%myEnergy > 0.8))
            %useWeapon = "SolarCharge";
          else if (%hasHornet && (%myEnergy > 0.6 || !%hasSolarCharge))  // %myEnergy > 0.6 to prevent firing hornets while a slow solar charge is on its way to the target - pinkpanther 07/22/04
            %useWeapon = "Hornet";
          else if (%hasMortar)
            %useWeapon = "Mortar";
          else if (%hasTitanChaingun)
            %useWeapon = "TitanChaingun";
          else if (%hasDisc)
            %useWeapon = "Disc";
          else if (%hasGatlingGun)
            %useWeapon = "GatlingGun";
          else if (%hasBlaster)
            %useWeapon = "Blaster";
      }
      else if (%distToTarg > 150 && !%inWater)
      {
          if (%hasSolarCharge && (%myEnergy > 0.8))
            %useWeapon = "SolarCharge";
          else if (%hasHornet && (%myEnergy > 0.6 || !%hasSolarCharge))  // %myEnergy > 0.6 to prevent firing hornets while a slow solar charge is on its way to the target - pinkpanther 07/22/04
            %useWeapon = "Hornet";
          else if (%hasMortar)
            %useWeapon = "Mortar";
      }
   }
   //else see if we're MDestroying the object -- Made new mode just in case -- Lagg... 1-12-2003
   else if (%mode $= "MDestroy")
   {
      if (%distToTarg < 15)
      {
          //if (%hasELF && %myEnergy > 0.4)
            //%useWeapon = ELFGun;
          if (%hasBlaster)
            %useWeapon = "Blaster";
          else if (%hasChain)
            %useWeapon = "Chaingun";
          else if (%hasPlasma)
            %useWeapon = "Plasma";
          else if (%hasDisc)
            %useWeapon = "Disc";
      }
      else if (%distToTarg < 150)
      {
          if (%hasMortar)
             %useWeapon = "Mortar";
          else if (%hasDisc)
             %useWeapon = "Disc";
          else if (%hasBlaster)
             %useWeapon = "Blaster";
      }
      else if (%distToTarg < 300)
      {
          //if (%hasMissile)
            //%useWeapon = "MissileLauncher";
          if (%hasMortar)
               %useWeapon = "Mortar";
      }
   }
   //else see if we're VDestroying the object -- Made new mode just in case -- Lagg... 1-12-2003
   else if (%mode $= "VDestroy")
   {
      if (%distToTarg < 75)
      {
          //if (%hasELF && %myEnergy > 0.4)
            //%useWeapon = ELFGun;
          if (%hasChain)
            %useWeapon = "Chaingun";
          else if (%hasDisc)
            %useWeapon = "Disc";
          else if (%hasPlasma)
            %useWeapon = "Plasma";
          else if (%hasBlaster)
            %useWeapon = "Blaster";
      }
      else if (%distToTarg < 150)
      {
          if (%hasMissile)
            %useWeapon = "MissileLauncher";
          else if (%hasMortar)
             %useWeapon = "Mortar";
          else if (%hasDisc)
             %useWeapon = "Disc";
          else if (%hasBlaster)
             %useWeapon = "Blaster";
          else if (%hasChain)
             %useWeapon = "Chaingun";
      }
      else if (%distToTarg < 300)
      {
          if (%hasMissile)
            %useWeapon = "MissileLauncher";
          if (%hasMortar)
               %useWeapon = "Mortar";
      }
   }
   //else see if we're missiling the object
   else if (%mode $= "Missile" || %mode $= "MissileNoLock")
   {
      if (%distToTarg > 40)
      {
          if (%hasMissile)
            %useWeapon = "MissileLauncher";
          else if (%hasHornet)
            %useWeapon = "Hornet";
      }
   }

   //now select the weapon
   switch$ (%useWeapon)
   {
      case "Blaster":
         %client.player.use("Blaster");
         %client.setWeaponInfo("EnergyBolt", 25, 150, 1, 0.1);

      case "Plasma":
         %client.player.use("Plasma");
         %client.setWeaponInfo("PlasmaBolt", 25, 50);

      case "Chaingun":
         %client.player.use("Chaingun");
         %client.setWeaponInfo("ChaingunBullet", 30, 75, 150);

      case "Disc":
         %client.player.use("Disc");
         %client.setWeaponInfo("DiscProjectile", 30, 150);

      case "GrenadeLauncher":
         %client.player.use("GrenadeLauncher");
         %client.setWeaponInfo("BasicGrenade", 40, 75);

      case "Mortar":
         %client.player.use("Mortar");
         %client.setWeaponInfo("MortarShot", 40, 300);

      case "SniperRifle":
         %client.player.use("SniperRifle");
         %client.setWeaponInfo("BasicSniperShot", 40, 700, 1, 0.75, 0.5);

      case "RepairPack"://added a little fix here - Lagg... 4-9-2003
	   if (%player.getImageState($BackpackSlot) $= "Idle")
	      %client.player.use("RepairPack");
         if (%player.getImageState($BackpackSlot) $= "Activate")
         {
            if(%client.player.getMountedImage($WeaponSlot).getName() !$= "RepairGunImage")
               %client.player.use("RepairPack");

            %client.setWeaponInfo("DefaultRepairBeam", 40, 75, 300, 0.1);
         }

         //if ( !%client.player.getImageTrigger( $BackpackSlot ) )
            //%client.player.setImageTrigger( $BackpackSlot, true );
         //if ( %client.player.getImageTrigger( $BackpackSlot ) )
            //%client.setWeaponInfo("DefaultRepairBeam", 40, 75, 300, 0.1);

      case "TargetingLaser":
         %client.player.use("TargetingLaser");
         %client.setWeaponInfo("BasicTargeter", 20, 300, 300, 0.1);

      case "MissileLauncher":
         %client.player.use("MissileLauncher");
         %client.setWeaponInfo("ShoulderMissile", 40, 300);

      case "ELFGun":
         %client.player.use("ELFGun");
         %client.setWeaponInfo("BasicELF", 25, 45, 90, 0.1);

      case "ShockLance":
         %client.player.use("ShockLance");
         %client.setWeaponInfo("BasicShocker", 0.5, 16, 1, 0.1);

   // ----- Triumph specific weapons here: pinkpanther 07/21/04  -----
   // I'm not sure at all about the %client.setWeaponInfo() parameters here!!!

      case "AntiAirGun":	// pinkpanther 07/21/04
         %client.player.use("AntiAirGun");
         %client.setWeaponInfo("AntiAirGunBolt", 20, 300);

      case "BeamSword":
         %client.player.use("BeamSword");
         %client.setWeaponInfo("LightBeam", 1, 5, 20);

      case "DualBlaster":
         %client.player.use("DualBlaster");
         %client.setWeaponInfo("DualEnergyBolt", 15, 250, 1, 0.1);

      case "ElfCannon":
         %client.player.use("ElfCannon");
         %client.setWeaponInfo("ELFTurretBolt", 25, 75, 175, 0.1);

      case "GatlingGun":
         %client.player.use("GatlingGun");
         %client.setWeaponInfo("GatlingGunBullet", 15, 100, 250);

      case "HeadHunter":
         %client.player.use("HeadHunter");
         %client.setWeaponInfo("HeadHunterSniperShot", 40, 1000, 1, 0.75, 0.5);

      case "HeavyLauncher":
         %client.player.use("HeavyLauncher");
         %client.setWeaponInfo("HeavyGrenade", 40, 175);

      case "Hornet":
//         %client.aimAt(%targetClient, 4000);	// not sure what this means.  pinkpanther 07/21/04
         %client.player.use("Hornet");
         %client.setWeaponInfo("HornetProjectile", 41, 300);

      case "Napalm":
         %client.player.use("Napalm");
         %client.setWeaponInfo("NapalmBolt", 2, 20);

      case "RailNade":
         %client.player.use("RailNade");
         %client.setWeaponInfo("RailNadeProjectile", 10, 175);

      case "SlugRifle":
         %client.player.use("SlugRifle");
         %client.setWeaponInfo("SlugRifleBullet", 10, 700);

      case "Shotgun":
         %client.player.use("Shotgun");
         %client.setWeaponInfo("ShotgunBullet", 1, 40);

      case "SolarCharge":
         %client.player.use("SolarCharge");
         %client.setWeaponInfo("SolarChargeBolt", 50, 300);

      case "TitanChaingun":
         %client.player.use("TitanChaingun");
         %client.setWeaponInfo("TitanChaingunBullet", 1, 30, 100);

      case "NoAmmo":
         %client.setWeaponInfo("NoAmmo", 30, 75);
   }
}

//-------------------------------------------

//big modifications here - Lagg... - 4-12-2003
function AIChooseEngageWeapon(%client, %targetClient, %distToTarg, %canUseEnergyStr, %environmentStr)
{
   //get some status
   %player = %client.player;
   if (!isObject(%player))
      return;

   %enemy = %targetClient.player;
   if (!isObject(%enemy))
      return;

   %enemyPos = %targetClient.player.getWorldBoxCenter();

   //added a check to call function for bots in vehicle - Lagg...
   if (%client.player.isMounted())
   {
      AIProcessVehicle(%client);//added this call to help bomber/gunner bot - Lagg...
      //check for LOS
      %vehicleLOS = "false";
      %mask = $TypeMasks::TerrainObjectType | $TypeMasks::InteriorObjectType | $TypeMasks::TSStaticShapeObjectType | $TypeMasks::VehicleObjectType;
      %vehicleLOS = !containerRayCast(%client.player.getWorldBoxCenter(), %enemyPos, %mask, 0);
      if (! %vehicleLos)
      {
         //clear the pressFire
	   %client.pressFire(-1);
         %client.setEngageTarget(-1);
         return;
      }
   }

   %canUseEnergy = (%canUseEnergyStr $= "true");
   %inWater = (%environmentStr $= "water");
   %outdoors = (%environmentStr $= "outdoors");
   %targVelocity = %targetClient.player.getVelocity();
   %targEnergy = %targetClient.player.getEnergyPercent();
   %targDamage = %targetClient.player.getDamagePercent();
   %myEnergy = %player.getEnergyPercent();
   %myDamage = %player.getDamagePercent();
   %hasLOS = %client.hasLOSToClient(%targetClient);//added - Lagg...
   %myArmor = %player.getArmorSize();//added - Lagg...
   %targIsPilot = %enemy.isMounted() > 0;

   //added this here to fix for elf gun - Lagg...
   %speed = VectorDist("0 0 0", %targVelocity);
   %myZ = getWord(%player.getTransform(), 2);
   %targetZ = getWord(%enemy.getTransform(), 2);
   %targetZVel = getWord(%targVelocity, 2);

   //find out the enemy's altitude - lagg...
   //%enemyPos = %targetClient.player.getWorldBoxCenter();
   %mask = $TypeMasks::TerrainObjectType | $TypeMasks::InteriorObjectType | $TypeMasks::ForceFieldObjectType;
   %downVect = getWord(%enemyPos, 0) @ " " @ getWord(%enemyPos, 1) @ "0";
   %altSur = containerRayCast(%enemyPos, %downVec, %mask, 0);
   %altPos = posfromRayCast(%altSur);
   %enemyAlt = getWord(%enemyPos, 2) - getWord(%altPos, 2);

   //lets get the enemy's heat
   %targetHeat = %targetClient.player.getHeat();

   %client.enviroment = %inwater; // Capto Lamia for this one
   //%client.enviromental = %outdoors;// not used standing on a roof counts as indoors :(

   //get our inventory
   %hasBlaster = (%player.getInventory("Blaster") > 0) && %canUseEnergy;
   %hasPlasma = (%player.getInventory("Plasma") > 0) && (%player.getInventory("PlasmaAmmo") > 0) && !%inWater;
   %hasChain = (%player.getInventory("Chaingun") > 0) && (%player.getInventory("ChaingunAmmo") > 0);
   %hasDisc = (%player.getInventory("Disc") > 0) && (%player.getInventory("DiscAmmo") > 0);
   %hasGrenade = (%player.getInventory("GrenadeLauncher") > 0) && (%player.getInventory("GrenadeLauncherAmmo") > 0) && !%inWater;
   %hasSniper = (%player.getInventory("SniperRifle") > 0) && (%player.getInventory("EnergyPack") > 0) && %canUseEnergy && !%inWater && %hasLOS; // added LOS - pinkpanther - 07/22/04
   %hasELF = (%player.getInventory("ELFGun") > 0) && %canUseEnergy && !%inWater;
   %hasMortar = (%player.getInventory("Mortar") > 0) && (%player.getInventory("MortarAmmo") > 0) && !%inWater;
   %hasMissile = (%player.getInventory("MissileLauncher") > 0) && (%player.getInventory("MissileLauncherAmmo") > 0) && !%inWater;
   %hasShockLance = (%player.getInventory("ShockLance") > 0) && %canUseEnergy && !%inWater;
   // ----- Triumph specific weapons here: pinkpanther 07/21/04  -----
   %hasAntiAirGun    = (%player.getInventory("AntiAirGun") > 0 && %player.getInventory("AntiAirGunAmmo") > 0) && !%inWater;
   %hasBeamSword     = (%player.getInventory("BeamSword") > 0 && (%distToTarg < 18) && %canUseEnergy && %hasLOS);
   %hasDualBlaster   = (%player.getInventory("DualBlaster") > 0 && %canUseEnergy && %hasLOS);
   %hasElfCannon     = (%player.getInventory("ElfCannon") > 0 && %canUseEnergy) && !%inWater;
   %hasGatlingGun    = (%player.getInventory("GatlingGun") > 0 && %player.getInventory("GatlingGunAmmo") > 0);
   %hasHeadHunter    = (%player.getInventory("HeadHunter") > 0) && (%player.getInventory("EnergyPack") > 0 && %canUseEnergy) && !%inWater && %hasLOS;
   %hasHeavyLauncher = (%player.getInventory("HeavyLauncher") > 0 && %player.getInventory("HeavyLauncherAmmo") > 0) && !%inWater;
   %hasHornet        = (%player.getInventory("Hornet") > 0 && %player.getInventory("HornetAmmo") > 0) && !%inWater && %hasLOS;
   %hasNapalm        = (%player.getInventory("Napalm") > 0 && %canUseEnergy) && !%inWater && %hasLOS;
   %hasRailNade      = (%player.getInventory("RailNade") > 0 && %player.getInventory("RailNadeAmmo") > 0) && !%inWater && %hasLOS;
   %hasShotgun       = (%player.getInventory("Shotgun") > 0 && %player.getInventory("ShotgunAmmo") > 0) && !%inWater && %hasLOS;
   %hasSlugRifle     = (%player.getInventory("SlugRifle") > 0 && %player.getInventory("SlugRifleAmmo") > 0) && !%inWater && %hasLOS;
   %hasSolarCharge   = (%player.getInventory("SolarCharge") > 0 && %canUseEnergy) && !%inWater && %outdoors && %hasLOS; // you better have LOS and are outdoors wth this ;-)
   %hasTitanChaingun = (%player.getInventory("TitanChaingun") > 0 && %player.getInventory("TitanChaingunAmmo") > 0);

   //choose the weapon
   %useWeapon = "NoAmmo";

   //first, see if it's a pilot we're shooting    --------------------------- Fix Lagg... 11/24/2002
       //this one makes a big differance in the way bots handle vehicles :)
      // many, many modifications    ------------------ pinkpanther - 07/22/04
   if (%distToTarg > 10 && %targIsPilot && %hasAntiAirGun)
      %useWeapon = "AntiAirGun";
   else if (%distToTarg > 20 && %targIsPilot && %hasMissile)
      %useWeapon = "MissileLauncher";
   else if (%distToTarg < 100 && %targIsPilot && %hasHornet && (%targVelocity < 1.0))
      %useWeapon = "Hornet";
   else if (%distToTarg < 150 && %targIsPilot && %hasGatlingGun && %hasLOS)
      %useWeapon = "GatlingGun";
   else if (%distToTarg < 100 && %targIsPilot && %hasChain && %hasLOS)
      %useWeapon = "Chaingun";
   else if (%distToTarg < 10 && %hasShockLance)
      %useWeapon = "ShockLance";

   else if (%distToTarg < 25)
   {
      if (%hasShotgun)	//	Most efficient within 25m
         %useWeapon = "Shotgun";
      else if (%hasBeamSword)
         %useWeapon = "BeamSword";
      else if (%hasNapalm && %myEnergy > 0.1)
         %useWeapon = "Napalm";
      else if (%outdoors && %hasMissile && %enemyAlt > 40.0 && %targetHeat > 0.69 && %hasLOS)
      {
         %client.aimAt(%targetClient, 3000);
         %useWeapon = "MissileLauncher";
      }
      else if (%hasShockLance && (%myArmor $= "Light" || %myArmor $= "Medium"))//added so assassin bots kill like assassins :) - Lagg...
         %useWeapon = "ShockLance";
      else if (%hasElfCannon && %myEnergy > 0.4 && %targEnergy > 0.3 && %myDamage < %targDamage && %targetZ > %myZ + 10)
         %useWeapon = "ElfCannon";
      else if (%hasELF && %myEnergy > 0.5 && %targEnergy > 0.3 && %myDamage < %targDamage && %targetZ > %myZ + 10)
         %useWeapon = "ELFGun";
      else if (%hasTitanChaingun)
         %useWeapon = "TitanChaingun";
      else if (%hasHornet && %enemyAlt < 8.0)
         %useWeapon = "Hornet";
      else if (%hasRailNade && %enemyAlt < 8.0 && %hasLOS)
         %useWeapon = "RailNade";
      else if (%hasPlasma && %hasLOS)//added los check - Lagg...
      	 %useWeapon = "Plasma";
      else if (%hasChain && %hasLOS)//added los check - Lagg...
         %useWeapon = "Chaingun";
      else if (%hasGatlingGun)
         %useWeapon = "GatlingGun";
      else if (%hasDualBlaster)
         %useWeapon = "DualBlaster";
      else if (%hasBlaster)
         %useWeapon = "Blaster";
      else if (%hasELF && %targEnergy > 0.2)
         %useWeapon = "ELFGun";
      else if (%hasDisc)
         %useWeapon = "Disc";
      else if (%hasShockLance)
	 %useWeapon = "ShockLance";
   }
   else if (%distToTarg < 45)
   {
      if (%outdoors && %hasMissile && %enemyAlt > 40.0 && %targetHeat > 0.69 && %hasLOS)
      {
         %client.aimAt(%targetClient, 3000);
         %useWeapon = "MissileLauncher";
      }
      else if (%hasElfCannon && %myEnergy > 0.4 && %targEnergy > 0.3 && %myDamage < %targDamage && %targetZ > %myZ + 10 && %hasLOS)
         %useWeapon = "ElfCannon";
      else if (%hasELF && %targEnergy > 0.4 && (%myDamage < 0.3 || %myDamage - %targDamage < 0.2) && %targetZ > %myZ + 10)
         %useWeapon = "ELFGun";
      else if (%hasSolarCharge && (%myEnergy > 0.8) && (%targVelocity < 1.0))
         %useWeapon = "SolarCharge";
      else if (%hasTitanChaingun)
         %useWeapon = "TitanChaingun";
      else if (%hasRailNade && %enemyAlt < 8.0 && %hasLOS)
         %useWeapon = "RailNade";
      else if (%hasHornet && %enemyAlt < 8.0)
         %useWeapon = "Hornet";
      else if (%hasDisc && %enemyAlt < 8.0)
         %useWeapon = "Disc";
      else if (!%outdoors && %hasPlasma && %hasLOS)//added los check - Lagg...
	      %useWeapon = "Plasma";
      else if (%hasHeavyLauncher && %enemyAlt < 8.0 && %targetZ < %myZ && %hasLOS)
         %useWeapon = "HeavyLauncher";
      else if (%hasGrenade && %enemyAlt < 8.0 && %targetZ < %myZ && %hasLOS)
         %useWeapon = "GrenadeLauncher";
      else if (%hasDualBlaster)
         %useWeapon = "DualBlaster";
      else if (!%outdoors && %hasMortar && %enemyAlt < 16.0 && %hasLOS)//added los check - Lagg...
      	 %useWeapon = "Mortar";
      else if ((%hasChain || %hasGatlingGun) && %hasDisc && %hasLOS)//added los check - Lagg...
      {
         if (%speed > 15.0 || %targetZ > %myZ || %targetZVel > 1.0)
         {
            if (%hasGatlingGun)
               %useWeapon = "GatlingGun";
            else
               %useWeapon = "Chaingun";
         }
         else
            %useWeapon = "Disc";
      }
      else if (%hasDisc)
         %useWeapon = "Disc";
      else if (%hasPlasma && %hasLOS)//added los check - Lagg...
        %useWeapon = "Plasma";
      else if (%hasGatlingGun)
         %useWeapon = "GatlingGun";
      else if (%hasChain && %hasLOS)//added los check - Lagg...
         %useWeapon = "Chaingun";
      else if (%hasBlaster)
         %useWeapon = "Blaster";
      else if (%hasShotgun)
         %useWeapon = "Shotgun";
   }
   else if (%distToTarg < 75)
   {
      if (%hasElfCannon && %myEnergy > 0.4 && %targEnergy > 0.3 && %myDamage < %targDamage && %targetZ > %myZ + 10)
         %useWeapon = "ElfCannon";
      else if (%outdoors && %hasMissile && %enemyAlt > 8.0 && %targetHeat > 0.69 && %hasLOS)
      {
         %client.aimAt(%targetClient, 3000);
         %useWeapon = "MissileLauncher";
      }
      else if (%hasSolarCharge && (%myEnergy > 0.8) && (%targVelocity < 1.0))
         %useWeapon = "SolarCharge";
      else if (%hasHeavyLauncher && %enemyAlt < 8.0 && %myZ - %targetZ > 20)
         %useWeapon = "HeavyLauncher";
      else if (%hasTitanChaingun)
         %useWeapon = "TitanChaingun";
      else if (%hasHornet && %enemyAlt < 8.0)
         %useWeapon = "Hornet";
      else if (%hasRailNade && %enemyAlt < 8.0 && %hasLOS)
         %useWeapon = "RailNade";
      else if (%hasGrenade && %enemyAlt < 8.0 && %hasLOS)
         %useWeapon = "GrenadeLauncher";
      else if (%hasMortar && %enemyAlt < 16.0 && %hasLOS)
	       %useWeapon = "Mortar";
      else if (%hasGatlingGun)
         %useWeapon = "GatlingGun";
      else if (%hasChain && %hasLOS)//added los check - Lagg...
         %useWeapon = "Chaingun";
      else if (%hasDisc)
         %useWeapon = "Disc";
      else if (%hasSlugRifle && (%targVelocity < 1.0))
         %useWeapon = "SlugRifle";
      else if (%hasHeadHunter && %myEnergy > 0.4)
         %useWeapon = "HeadHunter";
      else if (%hasSniper && %myEnergy > 0.6)
         %useWeapon = "SniperRifle";
      else if (%hasDualBlaster)
         %useWeapon = "DualBlaster";
      else if (%hasBlaster)
         %useWeapon = "Blaster";

   }
   else if (%distToTarg < 120)
   {
      if (%hasElfCannon && %myEnergy > 0.4 && %targEnergy > 0.3 && %myDamage < %targDamage && %targetZ > %myZ + 10)
         %useWeapon = "ElfCannon";
      else if (%outdoors && %hasMissile && %enemyAlt > 10.0 && %targetHeat > 0.69 && %hasLOS)
      {
         %client.aimAt(%targetClient, 3000);
         %useWeapon = "MissileLauncher";
      }
      else if (%hasSlugRifle && (%targVelocity < 1.0))
         %useWeapon = "SlugRifle";
      else if (%hasHeadHunter && %myEnergy > 0.4 && (%targVelocity < 1.0))
         %useWeapon = "HeadHunter";
      else if (%hasSniper && %myEnergy > 0.4)
         %useWeapon = "SniperRifle";
      else if (%hasSolarCharge && (%myEnergy > 0.8) && (%targVelocity < 1.0))
         %useWeapon = "SolarCharge";
      else if (%hasHeavyLauncher && %enemyAlt < 10.0 && %myZ - %targetZ > 50)
         %useWeapon = "HeavyLauncher";
      else if (%hasMortar && %enemyAlt < 5.0 && %hasLOS)//added los check - Lagg...
         %useWeapon = "Mortar";
      else if (%hasRailNade && %enemyAlt < 8.0 && %hasLOS)
         %useWeapon = "RailNade";
      else if (%hasGrenade && %enemyAlt < 10.0 && %myZ - %targetZ > 50)
         %useWeapon = "GrenadeLauncher";
      else if (%hasHornet && %enemyAlt < 10.0)
         %useWeapon = "Hornet";
      else if (%hasGatlingGun)
         %useWeapon = "GatlingGun";
      else if (%hasDisc)
         %useWeapon = "Disc";
      else if (%hasTitanChaingun)
         %useWeapon = "TitanChaingun";
      else if (%hasChain && %hasLOS)//added los check - Lagg...
         %useWeapon = "Chaingun";
      else if (%hasDualBlaster)
         %useWeapon = "DualBlaster";
      else if (%hasBlaster)
         %useWeapon = "Blaster";
   }
   else if (%distToTarg < 250)
   {
      //if (%outdoors && %hasMissile && %speed > 12.0 && %targEnergy < 0.4 && %hasLOS)
      if (%outdoors && %hasMissile && %targetHeat > 0.69 && %hasLOS)
      {
         %client.aimAt(%targetClient, 3000);
         %useWeapon = "MissileLauncher";
      }
      else if (%hasSlugRifle && (%targVelocity < 1.0))
         %useWeapon = "SlugRifle";
      else if (%hasHornet && (%targVelocity < 1.0))
         %useWeapon = "Hornet";
      else if (%hasHeadHunter && %myEnergy > 0.4 && (%targVelocity < 1.0))
         %useWeapon = "HeadHunter";
      else if (%hasSniper && %myEnergy > 0.4)
         %useWeapon = "SniperRifle";
      else if (%hasSolarCharge && (%myEnergy > 0.8) && (%targVelocity < 1.0))
         %useWeapon = "SolarCharge";
      else if (%hasMortar && %hasLOS)//added los check - Lagg...
         %useWeapon = "Mortar";
      else if (%hasDisc)
         %useWeapon = "Disc";
      else if (%hasGatlingGun)
         %useWeapon = "GatlingGun";
      else if (%hasHornet && %enemyAlt < 10.0)
         %useWeapon = "Hornet";
      else if (%hasDualBlaster)
         %useWeapon = "DualBlaster";
      else if (%hasBlaster)
         %useWeapon = "Blaster";
   }
   else
   {
      //if (%outdoors && %hasMissile && %speed > 12.0 && %targEnergy < 0.4 && %hasLOS)
      if (%outdoors && %hasMissile && %targetHeat > 0.69 && %hasLOS)
      {
         %client.aimAt(%targetClient, 3000);
         %useWeapon = "MissileLauncher";
      }
      else if (%hasSlugRifle && (%targVelocity < 1.0))
         %useWeapon = "SlugRifle";
      else if (%hasHeadHunter && %myEnergy > 0.4 && (%targVelocity < 1.0))
         %useWeapon = "HeadHunter";
      else if (%hasSniper)
         %useWeapon = "SniperRifle";
      else if (%hasSolarCharge && (%myEnergy > 0.8))
         %useWeapon = "SolarCharge";
      else if (%hasHornet && (%targVelocity < 1.0))
         %useWeapon = "Hornet";
      else if (%hasMortar && %hasLOS)//added los check - Lagg...
         %useWeapon = "Mortar";
   }
   //now make sure we actually selected something
   if (%useWeapon $= "NoAmmo")
   {
      if (%hasDisc)
         %useWeapon = "Disc";

      else if (%hasRailNade)
         %useWeapon = "RailNade";
      //else if (%outdoors && %hasMissile && %speed > 12.0 && %targEnergy < 0.4 && %hasLOS)
      else if (%outdoors && %hasMissile && %targetHeat > 0.69 && %hasLOS)
      {
         %client.aimAt(%targetClient, 3000);
         %useWeapon = "MissileLauncher";
      }
      else if (%hasDualBlaster)
         %useWeapon = "DualBlaster";
      else if (%hasGatlingGun)
         %useWeapon = "GatlingGun";
      else if (%hasHornet)
         %useWeapon = "Hornet";
      else if (%hasHeavyLauncher)
         %useWeapon = "HeavyLauncher";
      else if (%hasMortar && %hasLOS)//added los check - Lagg...
         %useWeapon = "Mortar";
      else if (%hasChain && %hasLOS)//added los check - Lagg...
         %useWeapon = "Chaingun";
      else if (%hasPlasma && %hasLOS)//added los check - Lagg...
         %useWeapon = "Plasma";
      else if (%hasGrenade && %hasLOS)//added los check - Lagg...
         %useWeapon = "GrenadeLauncher";
      else if (%hasBlaster)
         %useWeapon = "Blaster";
      else if (%hasSolarCharge)
         %useWeapon = "SolarCharge";
      else if (%hasSlugRifle)
         %useWeapon = "SlugRifle";
      else if (%hasTitanChaingun)
         %useWeapon = "TitanChaingun";
      else if (%hasHeadHunter)
         %useWeapon = "HeadHunter";
      else if (%hasSniper)
         %useWeapon = "SniperRifle";
      else if (%hasShockLance)
         %useWeapon = "ShockLance";
      else if (%hasElfCannon)
         %useWeapon = "ElfCannon";
      else if (%hasNapalm)
         %useWeapon = "Napalm";
      else if (%hasShotgun)
         %useWeapon = "Shotgun";
      else if (%hasBeamSword)
         %useWeapon = "BeamSword";
      else if (%hasELF)
         %useWeapon = "ELFGun";
      else if (%hasAntiAirGun)
         %useWeapon = "AntiAirGun";
   }

   //now select the weapon
   switch$ (%useWeapon)
   {
      case "Blaster":
         %client.player.use("Blaster");
         %client.setWeaponInfo("EnergyBolt", 25, 150, 1, 0.1);

      case "Plasma":
         %client.player.use("Plasma");
         %client.setWeaponInfo("PlasmaBolt", 25, 50);

      case "Chaingun":
         %client.player.use("Chaingun");
         %client.setWeaponInfo("ChaingunBullet", 15, 75, 150);

      case "Disc":
         %client.player.use("Disc");
         %client.setWeaponInfo("DiscProjectile", 30, 150);

      case "GrenadeLauncher":
         %client.player.use("GrenadeLauncher");
         %client.setWeaponInfo("BasicGrenade", 40, 75);

      case "SniperRifle":
         %client.player.use("SniperRifle");
         %client.setWeaponInfo("BasicSniperShot", 40, 700, 1, 0.75, 0.5);

      case "ELFGun":
         %client.player.use("ELFGun");
         %client.setWeaponInfo("BasicELF", 25, 45, 90, 0.1);

      case "ShockLance":
         %client.player.use("ShockLance");
         %client.setWeaponInfo("BasicShocker", 0.5, 16, 1, 0.1);

      case "MissileLauncher":
         %client.aimAt(%targetClient, 4000);
         %client.player.use("MissileLauncher");
         %client.setWeaponInfo("ShoulderMissile", 41, 300);

      case "Mortar":
         %client.player.use("Mortar");
         %client.setWeaponInfo("MortarShot", 40, 400);

   // ----- Triumph specific weapons here: pinkpanther 07/21/04  -----
   // I'm not sure at all about the %client.setWeaponInfo() parameters here!!!

      case "AntiAirGun":	// pinkpanther 07/21/04
         %client.player.use("AntiAirGun");
         %client.setWeaponInfo("AntiAirGunBolt", 20, 300);

      case "BeamSword":
         %client.player.use("BeamSword");
         %client.setWeaponInfo("LightBeam", 1, 5, 20);

      case "DualBlaster":
         %client.player.use("DualBlaster");
         %client.setWeaponInfo("DualEnergyBolt", 15, 250, 1, 0.1);

      case "ElfCannon":
         %client.player.use("ElfCannon");
         %client.setWeaponInfo("ELFTurretBolt", 25, 75, 175, 0.1);

      case "GatlingGun":
         %client.player.use("GatlingGun");
         %client.setWeaponInfo("GatlingGunBullet", 15, 100, 250);

      case "HeadHunter":
         %client.player.use("HeadHunter");
         %client.setWeaponInfo("HeadHunterSniperShot", 40, 1000, 1, 0.75, 0.5);

      case "HeavyLauncher":
         %client.player.use("HeavyLauncher");
         %client.setWeaponInfo("HeavyGrenade", 40, 175);

      case "Hornet":
//         %client.aimAt(%targetClient, 4000);	// not sure what this means.  pinkpanther 07/21/04
         %client.player.use("Hornet");
         %client.setWeaponInfo("HornetProjectile", 41, 300);

      case "Napalm":
         %client.player.use("Napalm");
         %client.setWeaponInfo("NapalmBolt", 2, 20);

      case "RailNade":
         %client.player.use("RailNade");
         %client.setWeaponInfo("RailNadeProjectile", 10, 175);

      case "SlugRifle":
         %client.player.use("SlugRifle");
         %client.setWeaponInfo("SlugRifleBullet", 10, 700);

      case "Shotgun":
         %client.player.use("Shotgun");
         %client.setWeaponInfo("ShotgunBullet", 1, 40);

      case "SolarCharge":
         %client.player.use("SolarCharge");
         %client.setWeaponInfo("SolarChargeBolt", 50, 300);

      case "TitanChaingun":
         %client.player.use("TitanChaingun");
         %client.setWeaponInfo("TitanChaingunBullet", 1, 30, 100);

      case "NoAmmo":
         %client.setWeaponInfo("NoAmmo", 30, 75);
   }
}

//function is called once per frame, to handle packs, healthkits, grenades, etc...
//heh heh heh this one was fun to do - Lagg... - 12-2003
function AIProcessEngagement(%client, %target, %type, %projectile)
{
   %player = %client.player;
   if (!isObject(%player))
      return;

   //make sure we're still alive
   if (!AIClientIsAlive(%client))
      return;

   //clear the pressFire
   %client.pressFire(-1);

   //LEAVE THIS OUT OR FLARES NO WORK !!!
   //added a check to call function for bots in vehicle - Lagg...
   //if (%client.player.isMounted())
   //{
   //AIProcessVehicle(%client);//added this call to help bomber bot - Lagg...
   //check for LOS
   //%vehicleLOS = "false";
   //%mask = $TypeMasks::TerrainObjectType | $TypeMasks::InteriorObjectType |
   //$TypeMasks::TSStaticShapeObjectType | $TypeMasks::VehicleObjectType;
   //%vehicleLOS = !containerRayCast(%client.player.getWorldBoxCenter(), %enemyPos, %mask, 0);
   //if (! %vehicleLos)
   //{
   //clear the pressFire
   //%client.pressFire(-1);
   //%client.setEngageTarget(-1);
   //return;
   //}
   //}

   %inwater = %client.enviroment; // Capto Lamia for this one --
   %outdoors = %client.enviromental;

   //see if we have to use a repairkit
   %mounted = %player.isMounted();
   %myEnergy = %player.getEnergyPercent();//added for cloaking and sensorjammer packs - Lagg... - 4-9-2003
   //%tur = -1;//added for cloaking and sensorjammer packs - Lagg... - 4-9-2003

   if (%client.getSkillLevel() > 0.1 && %player.getDamagePercent() > 0.3 && %player.getInventory("RepairKit") > 0)
   {
      //add in a "skill" value to delay the using of the repair kit for up to 10 seconds...
      %elapsedTime = getSimTime() - %client.lastDamageTime;
      %skillValue = (1.0 - %client.getSkillLevel()) * (1.0 - %client.getSkillLevel());
      if (%elapsedTime > (%skillValue * 20000))
         %player.use("RepairKit");
   }

   //see if we've been blinded
   if (%player.getWhiteOut() > 0.6)
      %client.setBlinded(2000);

   //else see if there's a grenade in the vicinity...
   else
   {
      %count = $AIGrenadeSet.getCount();
      for (%i = 0; %i < %count; %i++)
      {
         %grenade = $AIGrenadeSet.getObject(%i);

         //make sure the grenade isn't ours
         //if (%grenade.sourceObject.client != %client) //----- taken out Lagg... 11/24/2002
         //{  //----------------------------------------------- taken out Lagg... 11/24/2002
         // A grenade is a danger no matter who threw it. Has great effect when mortaring
         //see if it's within 15 m
         if (VectorDist(%grenade.position, %client.player.position) < 15)
         {
            %client.setDangerLocation(%grenade.position, 30);
            break;
         }
         //}  //----------------------------------------------- taken out Lagg... 11/24/2002
      }
   }

   //if we're being hunted by a seeker projectile, throw a flare grenade
   //modified from Capto Lamias tailgunner script ------------------------------ Lagg... 1-13-2003
   //the bots will flare to protect any team owned object if in range to do so
   if (%player.getInventory("FlareGrenade") > 0)
   {
      %missileCount = MissileSet.getCount();
      for (%i = 0; %i < %missileCount; %i++)
      {
         %missile = MissileSet.getObject(%i);
         %missileTarg = (%missile.getTargetObject());
         if (%missileTarg.Team == %client.Team)
         {
            //see if the missile is within range
            if (VectorDist(%missile.getTransform(), %player.getTransform()) < 150)
            {
               if (VectorDist(%missileTarg.getTransform(), %player.getTransform()) < 75)
               {
                  %player.throwStrength = 2;
                  %player.use("FlareGrenade");
                  break;
               }
            }
         }
      }
   }

   //see what we're fighting
   switch$ (%type)
   {
      case "player":
         //make sure the target is alive
         if (AIClientIsAlive(%target))
         {
            //if the target is in range, and within 10-40 m, & heading in this direction,use grenade
            //but not if we are mounted in a vehicle - Lagg...
            if (!$AIDisableGrenades && %client.getSkillLevel() >= 0.3 && !%inwater && !%isMounted)
            {
               if (%player.getInventory("Grenade") > 0)
                  %grenadeType = "Grenade";
               else if (%player.getInventory("FlashGrenade") > 0)
                  %grenadeType = "FlashGrenade";
               else if (%player.getInventory("ConcussionGrenade") > 0)
                  %grenadeType = "ConcussionGrenade";
               //--------------------------------Capto Lamia for this one as well
               else if (%player.getInventory("Mine") > 0)
                  %grenadeType = "Mine";
               else %grenadeType = "";

               if (%grenadeType !$= "" && %client.targetInSight())
               {
                  //see if the predicted location of the target is within 10m
                  %targPos = %target.player.getWorldBoxCenter();
                  %clientPos = %player.getWorldBoxCenter();

                  //make sure we're not *way* above the target
                  if (getWord(%clientPos, 2) - getWord(%targPos, 2) < 3)
                  {
                     %dist = VectorDist(%targPos, %clientPos);
                     %direction = VectorDot(VectorSub(%clientPos, %targPos), %target.player.getVelocity());
                     %facing = VectorDot(VectorSub(%client.getAimLocation(), %clientPos), VectorSub(%targPos, %clientPos));
                     if (%dist > 20 && %dist < 45 && (%direction > 0.9 || %direction < -0.9) && (%facing > 0.9))
                     {
                        %player.throwStrength = 1.0;
                        %player.use(%grenadeType);
                     }
                  }
               }
            }
            //see if we have a shield pack that we need to use
            if (%player.getInventory("ShieldPack") > 0)
            {
               if (%projectile > 0 && %player.getImageState($BackpackSlot) $= "Idle")
                  %player.use("Backpack");
               else if (%projectile <= 0 && %player.getImageState($BackpackSlot) $= "activate")
                  %player.use("Backpack");
            }
            //see if we have a cloaking pack that we need to use -----Capto Lamia - Lagg modified... 4-13-2003
            if (%player.getInventory("CloakingPack") > 0)
            {
               if (%player.getImageState($BackpackSlot) $= "Idle" && %myEnergy > 0.4)
                  %player.use("Backpack");
               else if (%player.getImageState($BackpackSlot) $= "activate" && %myEnergy < 0.4)
                  %player.use("Backpack");
            }
            //see if we have a sensor jammer pack that we need to use ---------Capto Lamia - Lagg modified... 4-13-2003
            //thinking about a radius search for turrets, sensors, ect... - Lagg 1-13-2003
           if (%player.getInventory("SensorJammerPack") > 0)
           {
              if (%player.getImageState($BackpackSlot) $= "Idle" && %myEnergy > 0.4 && %client.targetInRange())
                 %player.use("Backpack");
              else if (%player.getImageState($BackpackSlot) $= "activate" && (%myEnergy < 0.4 || !%client.targetInRange()))
                 %player.use("Backpack");
           }
        }

      case "object":
         %hasGrenade = %player.getInventory("Grenade") > 0;
         if (%hasGrenade && %client.targetInRange() && !%inwater && !%mounted)
         {
            %targPos = %target.getWorldBoxCenter();
            %myPos = %player.getWorldBoxCenter();
            %dist = VectorDist(%targPos, %myPos);
            if (%dist > 5 && %dist < 20)
            {
               %player.throwStrength = 1.0;
               %player.use("Grenade");
            }
         }
         //Capto Lamia, add it here as well---------------- Lagg... 1-12-2003
         %hasmine = %player.getInventory("Mine") > 0;
         if (%hasMine && %client.targetInRange() && !%inwater)
         {
            //only throw a mine when killing gens or invos - Lagg... 4-12-2003
            %targ = %target.getDataBlock().getName();
            if ((%targ $= "StationInventory") || (%targ $= "GeneratorLarge") || (%targ $= "StationVehicle"))
            {
               %targPos = %target.getWorldBoxCenter();
               %myPos = %player.getWorldBoxCenter();
               %dist = VectorDist(%targPos, %myPos);
               if (%dist > 5 && %dist < 20)
               {
                  %player.throwStrength = 1.0;
                  %player.use("Mine");
               }
            }
         }
         //see if we have a cloaking pack that we need to use -----Capto Lamia - Lagg modified... 4-13-2003
         if (%player.getInventory("CloakingPack") > 0)
         {
            if (%player.getImageState($BackpackSlot) $= "Idle" && %myEnergy > 0.4 && %client.targetInRange())
               %player.use("Backpack");
            else if (%player.getImageState($BackpackSlot) $= "activate" && (%myEnergy < 0.4 || !%client.targetInRange()))
               %player.use("Backpack");
         }
         //see if we have a sensor jammer pack that we need to use ---------Capto Lamia
         //thinking about a radius search for turrets, sensors, ect... - Lagg 1-13-2003
         if (%player.getInventory("SensorJammerPack") > 0 && %client.targetInRange())
         {
            if (%player.getImageState($BackpackSlot) $= "Idle" && %myEnergy > 0.4 && %client.targetInRange())
               %player.use("Backpack");
            else if (%player.getImageState($BackpackSlot) $= "activate" && (%myEnergy < 0.4 || !%client.targetInRange()))
               %player.use("Backpack");
         }

      case "none":
         //use the repair pack if we have one and not right next to a target - Lagg... 3-29-2003
         if (%player.getDamagePercent() > 0 && %player.getInventory(RepairPack) > 0 && !%client.targetInRange())
         {
            //if (%player.getImageState($BackpackSlot) $= "Idle")
		//%client.player.use("RepairPack");
            //else if (%player.getImageState($BackpackSlot) $= "activate")
            //sustain the fire for 30 frames - this callback is timesliced...
            //%client.pressFire(30);
            //if (%player.getImageState($BackpackSlot) !$= "activate")
            //clear the fire if not using repairpack - Lagg... - 4-9-2003
            //%client.pressFire(-1);

            if (%player.getImageState($BackpackSlot) !$= "activate")
		   %client.player.use("RepairPack");
            else if (isObject(%client.player.getMountedImage($WeaponSlot)) && %client.player.getMountedImage($WeaponSlot).getName() $= "RepairGunImage")
               //sustain the fire for 30 frames - this callback is timesliced...
               %client.pressFire(30);
            else if (!isObject(%client.player.getMountedImage($WeaponSlot)) || %client.player.getMountedImage($WeaponSlot).getName() !$= "RepairGunImage")
               //clear the fire if not using repairpack - Lagg... - 4-9-2003
               %client.pressFire(-1);
         }
   }
}

//------------------------------------------------------------------------------

function AIFindClosestInventory(%client, %armorChange)
{
   %closestInv = -1;
   %closestDist = 32767;

   %depCount = 0;
   %depGroup = nameToID("MissionCleanup/Deployables");
   if (%depGroup > 0)
      %depCount = %depGroup.getCount();

   // there exists a deployed station, lets find it
   if(!%armorChange && %depCount > 0)
   {
      for(%i = 0; %i < %depCount; %i++)
      {
         %obj = %depGroup.getObject(%i);

         if(%obj.getDataBlock().getName() $= "DeployedStationInventory" && %obj.team == %client.team && %obj.isEnabled())
         {
            //make sure the inventory station is not blocked - lets add a check for parked vehicles :) - Lagg... 2-25-2004
	      %invLocation = %obj.getWorldBoxCenter();
            InitContainerRadiusSearch(%invLocation, 12, $TypeMasks::VehicleObjectType);
            %objSrch = containerSearchNext();

            %distance = %client.getPathDistance(%obj.getTransform());
            if (%distance > 0 && %distance < %closestDist && !%objSrch)
            {
               %closestInv = %obj;
               %closestDist = %distance;
            }
         }
      }
   }

   // still check if there is one that is closer
   %invCount = $AIInvStationSet.getCount();
   for (%i = 0; %i < %invCount; %i++)
   {
      %invStation = $AIInvStationSet.getObject(%i);
      if (%invStation.team <= 0 || %invStation.team == %client.team)
      {
         //error("DEBUG: found an inventory station: " @ %invStation @ "  status: " @ %invStation.isPowered());
         //make sure the station is powered
         if (!%invStation.isDisabled() && %invStation.isPowered())
         {
            %dist = %client.getPathDistance(%invStation.getTransform());
            if (%dist > 0 && %dist < %closestDist)
            {
               %closestInv = %invStation;
               %closestDist = %dist;
            }
         }
      }
   }
   return %closestInv @ " " @ %closestDist;
}

//------------------------------
//find the closest inventories for the objective weight functions
function AIFindClosestInventories(%client)
{
   %closestInv = -1;
   %closestDist = 32767;
   %closestRemoteInv = -1;
   %closestRemoteDist = 32767;

   %depCount = 0;
   %depGroup = nameToID("MissionCleanup/Deployables");

   //first, search for the nearest deployable inventory station
   if (isObject(%depGroup))
   {
      %depCount = %depGroup.getCount();
      for (%i = 0; %i < %depCount; %i++)
      {
         %obj = %depGroup.getObject(%i);
         if (%obj.getDataBlock().getName() $= "DeployedStationInventory" && %obj.team == %client.team && %obj.isEnabled())
         {
            //make sure the inventory station is not blocked - lets add a check for parked vehicles :) - Lagg... 2-25-2004
	      %invLocation = %obj.getWorldBoxCenter();
            InitContainerRadiusSearch(%invLocation, 12, $TypeMasks::VehicleObjectType);
            %objSrch = containerSearchNext();

            %distance = %client.getPathDistance(%obj.getTransform());
            if (%distance > 0 && %distance < %closestRemoteDist && !%objSrch)
            {
               %closestRemoteInv = %obj;
               %closestRemoteDist = %distance;
            }
         }
      }
   }

   // now find the closest regular inventory station
   %invCount = $AIInvStationSet.getCount();
   for (%i = 0; %i < %invCount; %i++)
   {
      %invStation = $AIInvStationSet.getObject(%i);
      if (%invStation.team <= 0 || %invStation.team == %client.team)
      {
         //make sure the station is powered
         if (!%invStation.isDisabled() && %invStation.isPowered())
         {
            %dist = %client.getPathDistance(%invStation.getTransform());
            if (%dist > 0 && %dist < %closestDist)
            {
               %closestInv = %invStation;
               %closestDist = %dist;
            }
         }
      }
   }

   //if the regular inv station is closer than the deployed, don't bother with the remote
   if (%closestDist < %closestRemoteDist)
      %returnStr = %closestInv SPC %closestDist;
   else
      %returnStr = %closestInv SPC %closestDist SPC %closestRemoteInv SPC %closestRemoteDist;

   return %returnStr;
}

//new function called from AIAttackObject and AIdestroyObject and aiDetectVehiculeTask - Lagg... - 4-12-2003
function AIAttackOutofAmmo(%client)
{
   //this function only cares about weapons used in engagement...
   //no mortars, or missiles - yeah right...Lagg
   %player = %client.player;
   if (!isObject(%player))
      return false;

   %ammoWeapons = 0;
   %energyWeapons = 0;

   //get our inventory
   %hasBlaster = (%player.getInventory("Blaster") > 0);
   %hasPlasma  = (%player.getInventory("Plasma") > 0);
   %hasChain   = (%player.getInventory("Chaingun") > 0);
   %hasDisc    = (%player.getInventory("Disc") > 0);
   %hasGrenade = (%player.getInventory("GrenadeLauncher") > 0);
   %hasSniper  = (%player.getInventory("SniperRifle") > 0) && (%player.getInventory("EnergyPack") > 0);
   %hasELF     = (%player.getInventory("ELFGun") > 0);
   %hasMortar  = (%player.getInventory("Mortar") > 0);
   %hasMissile = (%player.getInventory("MissileLauncher") > 0);
   %hasLance   = (%player.getInventory("ShockLance") > 0);
   // ----- Triumph specific weapons here: pinkpanther 07/21/04  -----
   %hasAntiAirGun    = (%player.getInventory("AntiAirGun") > 0);
   %hasDualBlaster   = (%player.getInventory("DualBlaster") > 0);
   %hasElfCannon     = (%player.getInventory("ElfCannon") > 0);
   %hasGatlingGun    = (%player.getInventory("GatlingGun") > 0);
   %hasHeadHunter    = (%player.getInventory("HeadHunter") > 0) && (%player.getInventory("EnergyPack") > 0);
   %hasHeavyLauncher = (%player.getInventory("HeavyLauncher") > 0);
   %hasHornet        = (%player.getInventory("Hornet") > 0);
   %hasNapalm        = (%player.getInventory("Napalm") > 0);
   %hasRailNade      = (%player.getInventory("RailNade") > 0);
   %hasShotgun       = (%player.getInventory("Shotgun") > 0);
   %hasSlugRifle     = (%player.getInventory("SlugRifle") > 0);
   %hasSolarCharge   = (%player.getInventory("SolarCharge") > 0);

   if (%hasBlaster || %hasSniper || %hasElf || %hasLance || %hasHeadHunter || %hasDualBlaster || %hasSolarCharge || %hasElfCannon || %hasNapalm)	// pinkpanther 07/21/04
      return false;
   else
   {
      // we only have ammo type weapons
      if(%hasDisc && (%player.getInventory("DiscAmmo") > 0))
         return false;
      else if(%hasChain && (%player.getInventory("ChainGunAmmo") > 0))
         return false;
      else if(%hasGrenade && (%player.getInventory("GrenadeLauncherAmmo") > 0))
         return false;
      else if(%hasPlasma && (%player.getInventory("PlasmaAmmo") > 0))
         return false;
      else if(%hasMissile && (%player.getInventory("MissileLauncherAmmo") > 0))
         return false;
      else if(%hasMortar && (%player.getInventory("MortarAmmo") > 0))
         return false;
   // ----- Triumph specific weapons here: pinkpanther 07/21/04  -----
      else if(%hasAntiAirGun && (%player.getInventory("AntiAirGunAmmo") > 0))
         return false;
      else if(%hasGatlingGun && (%player.getInventory("GatlingGunAmmo") > 0))
         return false;
      else if(%hasHeavyLauncher && (%player.getInventory("HeavyLauncherAmmo") > 0))
         return false;
      else if(%hasHornet && (%player.getInventory("HornetAmmo") > 0))
         return false;
      else if(%hasRailNade && (%player.getInventory("RailNadeAmmo") > 0))
         return false;
      else if(%hasShotgun && (%player.getInventory("ShotgunAmmo") > 0))
         return false;
      else if(%hasSlugRifle && (%player.getInventory("SlugRifleAmmo") > 0))
         return false;
   }
   return true; // were out!
}

//------------------------------------------------------------------------------------------------

// Too many modifications to mention -  7/22/04 pinkpanther@swissonline.ch

//AI Equipment Configs
$EquipConfigIndex = -1;
$AIEquipmentSet[HeavyEnergyDefault, $EquipConfigIndex++] = "Heavy";
$AIEquipmentSet[HeavyEnergyDefault, $EquipConfigIndex++] = "EnergyPack";
$AIEquipmentSet[HeavyEnergyDefault, $EquipConfigIndex++] = "Napalm";
$AIEquipmentSet[HeavyEnergyDefault, $EquipConfigIndex++] = "SolarCharge";
$AIEquipmentSet[HeavyEnergyDefault, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[HeavyEnergyDefault, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[HeavyEnergyDefault, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[HeavyEnergyDefault, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[HeavyEnergyDefault, $EquipConfigIndex++] = "Mortar";
$AIEquipmentSet[HeavyEnergyDefault, $EquipConfigIndex++] = "MortarAmmo";
$AIEquipmentSet[HeavyEnergyDefault, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[HeavyEnergyDefault, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[HeavyEnergyDefault, $EquipConfigIndex++] = "Grenade";
$AIEquipmentSet[HeavyEnergyDefault, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[HeavyAmmoSet, $EquipConfigIndex++] = "Heavy";
$AIEquipmentSet[HeavyAmmoSet, $EquipConfigIndex++] = "ShieldPack";
$AIEquipmentSet[HeavyAmmoSet, $EquipConfigIndex++] = "GatlingGun";
$AIEquipmentSet[HeavyAmmoSet, $EquipConfigIndex++] = "GatlingGunAmmo";
$AIEquipmentSet[HeavyAmmoSet, $EquipConfigIndex++] = "Plasma";
$AIEquipmentSet[HeavyAmmoSet, $EquipConfigIndex++] = "PlasmaAmmo";
$AIEquipmentSet[HeavyAmmoSet, $EquipConfigIndex++] = "SolarCharge";
$AIEquipmentSet[HeavyAmmoSet, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[HeavyAmmoSet, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[HeavyAmmoSet, $EquipConfigIndex++] = "Mortar";
$AIEquipmentSet[HeavyAmmoSet, $EquipConfigIndex++] = "MortarAmmo";
$AIEquipmentSet[HeavyAmmoSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[HeavyAmmoSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[HeavyAmmoSet, $EquipConfigIndex++] = "ConcussionGrenade";
$AIEquipmentSet[HeavyAmmoSet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[HeavyShieldSet, $EquipConfigIndex++] = "Heavy";
$AIEquipmentSet[HeavyShieldSet, $EquipConfigIndex++] = "ShieldPack";
$AIEquipmentSet[HeavyShieldSet, $EquipConfigIndex++] = "RailNade";
$AIEquipmentSet[HeavyShieldSet, $EquipConfigIndex++] = "RailNadeAmmo";
$AIEquipmentSet[HeavyShieldSet, $EquipConfigIndex++] = "Napalm";
$AIEquipmentSet[HeavyShieldSet, $EquipConfigIndex++] = "GatlingGun";
$AIEquipmentSet[HeavyShieldSet, $EquipConfigIndex++] = "GatlingGunAmmo";
$AIEquipmentSet[HeavyShieldSet, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[HeavyShieldSet, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[HeavyShieldSet, $EquipConfigIndex++] = "Mortar";
$AIEquipmentSet[HeavyShieldSet, $EquipConfigIndex++] = "MortarAmmo";
$AIEquipmentSet[HeavyShieldSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[HeavyShieldSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[HeavyShieldSet, $EquipConfigIndex++] = "FlareGrenade";
//$AIEquipmentSet[HeavyShieldSet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[HeavyShieldOff, $EquipConfigIndex++] = "Heavy";
$AIEquipmentSet[HeavyShieldOff, $EquipConfigIndex++] = "ShieldPack";
$AIEquipmentSet[HeavyShieldOff, $EquipConfigIndex++] = "Napalm";
$AIEquipmentSet[HeavyShieldOff, $EquipConfigIndex++] = "GatlingGun";
$AIEquipmentSet[HeavyShieldOff, $EquipConfigIndex++] = "GatlingGunAmmo";
$AIEquipmentSet[HeavyShieldOff, $EquipConfigIndex++] = "SolarCharge";
$AIEquipmentSet[HeavyShieldOff, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[HeavyShieldOff, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[HeavyShieldOff, $EquipConfigIndex++] = "Mortar";
$AIEquipmentSet[HeavyShieldOff, $EquipConfigIndex++] = "MortarAmmo";
$AIEquipmentSet[HeavyShieldOff, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[HeavyShieldOff, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[HeavyShieldOff, $EquipConfigIndex++] = "FlashGrenade";
$AIEquipmentSet[HeavyShieldOff, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[HeavyEnergySet, $EquipConfigIndex++] = "Heavy";
$AIEquipmentSet[HeavyEnergySet, $EquipConfigIndex++] = "EnergyPack";
$AIEquipmentSet[HeavyEnergySet, $EquipConfigIndex++] = "SolarCharge";
$AIEquipmentSet[HeavyEnergySet, $EquipConfigIndex++] = "Napalm";
$AIEquipmentSet[HeavyEnergySet, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[HeavyEnergySet, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[HeavyEnergySet, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[HeavyEnergySet, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[HeavyEnergySet, $EquipConfigIndex++] = "Mortar";
$AIEquipmentSet[HeavyEnergySet, $EquipConfigIndex++] = "MortarAmmo";
$AIEquipmentSet[HeavyEnergySet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[HeavyEnergySet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[HeavyEnergySet, $EquipConfigIndex++] = "FlashGrenade";
$AIEquipmentSet[HeavyEnergySet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[HeavyRepairSet, $EquipConfigIndex++] = "Heavy";
$AIEquipmentSet[HeavyRepairSet, $EquipConfigIndex++] = "RepairPack";
$AIEquipmentSet[HeavyRepairSet, $EquipConfigIndex++] = "Napalm";
$AIEquipmentSet[HeavyRepairSet, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[HeavyRepairSet, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[HeavyRepairSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[HeavyRepairSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[HeavyRepairSet, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[HeavyRepairSet, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[HeavyRepairSet, $EquipConfigIndex++] = "Mortar";
$AIEquipmentSet[HeavyRepairSet, $EquipConfigIndex++] = "MortarAmmo";
$AIEquipmentSet[HeavyRepairSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[HeavyRepairSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[HeavyRepairSet, $EquipConfigIndex++] = "FlareGrenade";
$AIEquipmentSet[HeavyRepairSet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
// Turret monkey must be FieldTech - pinkpanther
$AIEquipmentSet[HeavyIndoorTurretSet, $EquipConfigIndex++] = "FieldTech";
$AIEquipmentSet[HeavyIndoorTurretSet, $EquipConfigIndex++] = "TurretIndoorDeployable";
$AIEquipmentSet[HeavyIndoorTurretSet, $EquipConfigIndex++] = "ShockLance";
$AIEquipmentSet[HeavyIndoorTurretSet, $EquipConfigIndex++] = "Plasma";
$AIEquipmentSet[HeavyIndoorTurretSet, $EquipConfigIndex++] = "PlasmaAmmo";
$AIEquipmentSet[HeavyIndoorTurretSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[HeavyIndoorTurretSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[HeavyIndoorTurretSet, $EquipConfigIndex++] = "GatlingGun";
$AIEquipmentSet[HeavyIndoorTurretSet, $EquipConfigIndex++] = "GatlingGunAmmo";
$AIEquipmentSet[HeavyIndoorTurretSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[HeavyIndoorTurretSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[HeavyIndoorTurretSet, $EquipConfigIndex++] = "FlashGrenade";
//$AIEquipmentSet[HeavyIndoorTurretSet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
// Turret monkey must be FieldTech - pinkpanther
$AIEquipmentSet[HeavyOutdoorTurretSet, $EquipConfigIndex++] = "FieldTech";
$AIEquipmentSet[HeavyOutdoorTurretSet, $EquipConfigIndex++] = "TurretOutdoorDeployable";
$AIEquipmentSet[HeavyOutdoorTurretSet, $EquipConfigIndex++] = "ElfCannon";
$AIEquipmentSet[HeavyOutdoorTurretSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[HeavyOutdoorTurretSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[HeavyOutdoorTurretSet, $EquipConfigIndex++] = "GatlingGun";
$AIEquipmentSet[HeavyOutdoorTurretSet, $EquipConfigIndex++] = "GatlingGunAmmo";
$AIEquipmentSet[HeavyOutdoorTurretSet, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[HeavyOutdoorTurretSet, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[HeavyOutdoorTurretSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[HeavyOutdoorTurretSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[HeavyOutdoorTurretSet, $EquipConfigIndex++] = "FlareGrenade";
$AIEquipmentSet[HeavyOutdoorTurretSet, $EquipConfigIndex++] = "Mine";


$EquipConfigIndex = -1;
$AIEquipmentSet[HeavyInventorySet, $EquipConfigIndex++] = "Heavy";
$AIEquipmentSet[HeavyInventorySet, $EquipConfigIndex++] = "InventoryDeployable";
$AIEquipmentSet[HeavyInventorySet, $EquipConfigIndex++] = "Plasma";
$AIEquipmentSet[HeavyInventorySet, $EquipConfigIndex++] = "PlasmaAmmo";
$AIEquipmentSet[HeavyInventorySet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[HeavyInventorySet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[HeavyInventorySet, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[HeavyInventorySet, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[HeavyInventorySet, $EquipConfigIndex++] = "Napalm";
$AIEquipmentSet[HeavyInventorySet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[HeavyInventorySet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[HeavyInventorySet, $EquipConfigIndex++] = "FlashGrenade";
$AIEquipmentSet[HeavyInventorySet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "Heavy";
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "AmmoPack";
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "Chaingun";
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "ChaingunAmmo";
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "GatlingGun";
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "GatlingGunAmmo";
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "AntiAirGun";
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "AntiAirGunAmmo";
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "FlareGrenade";
$AIEquipmentSet[HeavyTailgunner, $EquipConfigIndex++] = "Mine";

//------------------------------

$EquipConfigIndex = -1;
$AIEquipmentSet[MediumRepairSet, $EquipConfigIndex++] = "Medium";
$AIEquipmentSet[MediumRepairSet, $EquipConfigIndex++] = "RepairPack";
$AIEquipmentSet[MediumRepairSet, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[MediumRepairSet, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[MediumRepairSet, $EquipConfigIndex++] = "Napalm";
$AIEquipmentSet[MediumRepairSet, $EquipConfigIndex++] = "HeavyLauncher";
$AIEquipmentSet[MediumRepairSet, $EquipConfigIndex++] = "HeavyLauncherAmmo";
$AIEquipmentSet[MediumRepairSet, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[MediumRepairSet, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[MediumRepairSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[MediumRepairSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[MediumRepairSet, $EquipConfigIndex++] = "FlareGrenade";
$AIEquipmentSet[MediumRepairSet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[MediumShieldSet, $EquipConfigIndex++] = "Medium";
$AIEquipmentSet[MediumShieldSet, $EquipConfigIndex++] = "ShieldPack";
$AIEquipmentSet[MediumShieldSet, $EquipConfigIndex++] = "Napalm";
$AIEquipmentSet[MediumShieldSet, $EquipConfigIndex++] = "GatlingGun";
$AIEquipmentSet[MediumShieldSet, $EquipConfigIndex++] = "GatlingGunAmmo";
$AIEquipmentSet[MediumShieldSet, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[MediumShieldSet, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[MediumShieldSet, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[MediumShieldSet, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[MediumShieldSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[MediumShieldSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[MediumShieldSet, $EquipConfigIndex++] = "FlareGrenade";
$AIEquipmentSet[MediumShieldSet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[MediumEnergySet, $EquipConfigIndex++] = "Medium";
$AIEquipmentSet[MediumEnergySet, $EquipConfigIndex++] = "EnergyPack";
$AIEquipmentSet[MediumEnergySet, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[MediumEnergySet, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[MediumEnergySet, $EquipConfigIndex++] = "HeavyLauncher";
$AIEquipmentSet[MediumEnergySet, $EquipConfigIndex++] = "HeavyLauncherAmmo";
$AIEquipmentSet[MediumEnergySet, $EquipConfigIndex++] = "Napalm";
$AIEquipmentSet[MediumEnergySet, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[MediumEnergySet, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[MediumEnergySet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[MediumEnergySet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[MediumEnergySet, $EquipConfigIndex++] = "ConcussionGrenade";
$AIEquipmentSet[MediumEnergySet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[MediumMissileSet, $EquipConfigIndex++] = "Medium";
$AIEquipmentSet[MediumMissileSet, $EquipConfigIndex++] = "AmmoPack";
$AIEquipmentSet[MediumMissileSet, $EquipConfigIndex++] = "RailNade";
$AIEquipmentSet[MediumMissileSet, $EquipConfigIndex++] = "RailNadeAmmo";
$AIEquipmentSet[MediumMissileSet, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[MediumMissileSet, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[MediumMissileSet, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[MediumMissileSet, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[MediumMissileSet, $EquipConfigIndex++] = "Napalm";
$AIEquipmentSet[MediumMissileSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[MediumMissileSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[MediumMissileSet, $EquipConfigIndex++] = "Grenade";
$AIEquipmentSet[MediumMissileSet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[MediumOutdoorTurretSet, $EquipConfigIndex++] = "FieldTech";      // Turret monkey must be FieldTech (needs Disk) - pinkpanther
$AIEquipmentSet[MediumOutdoorTurretSet, $EquipConfigIndex++] = "TurretOutdoorDeployable";
$AIEquipmentSet[MediumOutdoorTurretSet, $EquipConfigIndex++] = "ElfCannon";
$AIEquipmentSet[MediumOutdoorTurretSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[MediumOutdoorTurretSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[MediumOutdoorTurretSet, $EquipConfigIndex++] = "GatlingGun";
$AIEquipmentSet[MediumOutdoorTurretSet, $EquipConfigIndex++] = "GatlingGunAmmo";
$AIEquipmentSet[MediumOutdoorTurretSet, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[MediumOutdoorTurretSet, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[MediumOutdoorTurretSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[MediumOutdoorTurretSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[MediumOutdoorTurretSet, $EquipConfigIndex++] = "FlareGrenade";
$AIEquipmentSet[MediumOutdoorTurretSet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[MediumIndoorTurretSet, $EquipConfigIndex++] = "FieldTech";     // Turret monkey must be FieldTech (needs Disk) - pinkpanther
$AIEquipmentSet[MediumIndoorTurretSet, $EquipConfigIndex++] = "TurretIndoorDeployable";
$AIEquipmentSet[MediumIndoorTurretSet, $EquipConfigIndex++] = "Plasma";
$AIEquipmentSet[MediumIndoorTurretSet, $EquipConfigIndex++] = "PlasmaAmmo";
$AIEquipmentSet[MediumIndoorTurretSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[MediumIndoorTurretSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[MediumIndoorTurretSet, $EquipConfigIndex++] = "GatlingGun";
$AIEquipmentSet[MediumIndoorTurretSet, $EquipConfigIndex++] = "GatlingGunAmmo";
$AIEquipmentSet[MediumIndoorTurretSet, $EquipConfigIndex++] = "ShockLance";
$AIEquipmentSet[MediumIndoorTurretSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[MediumIndoorTurretSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[MediumIndoorTurretSet, $EquipConfigIndex++] = "FlashGrenade";
//$AIEquipmentSet[MediumIndoorTurretSet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[MediumInventorySet, $EquipConfigIndex++] = "Medium";
$AIEquipmentSet[MediumInventorySet, $EquipConfigIndex++] = "InventoryDeployable";
$AIEquipmentSet[MediumInventorySet, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[MediumInventorySet, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[MediumInventorySet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[MediumInventorySet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[MediumInventorySet, $EquipConfigIndex++] = "RailNade";
$AIEquipmentSet[MediumInventorySet, $EquipConfigIndex++] = "RailNadeAmmo";
$AIEquipmentSet[MediumInventorySet, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[MediumInventorySet, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[MediumInventorySet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[MediumInventorySet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[MediumInventorySet, $EquipConfigIndex++] = "FlashGrenade";
//$AIEquipmentSet[MediumInventorySet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "Medium";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "PulseSensorDeployable";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "Chaingun";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "ChaingunAmmo";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "GrenadeLauncher";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "GrenadeLauncherAmmo";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "ConcussionGrenade";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "Medium";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "MotionSensorDeployable";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "Chaingun";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "ChaingunAmmo";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "GrenadeLauncher";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "GrenadeLauncherAmmo";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "CameraGrenade";
//$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "Mine";

//------------------------------

$EquipConfigIndex = -1;
$AIEquipmentSet[LightEnergyDefault, $EquipConfigIndex++] = "Light";
$AIEquipmentSet[LightEnergyDefault, $EquipConfigIndex++] = "EnergyPack";
$AIEquipmentSet[LightEnergyDefault, $EquipConfigIndex++] = "Shotgun";
$AIEquipmentSet[LightEnergyDefault, $EquipConfigIndex++] = "ShotgunAmmo";
$AIEquipmentSet[LightEnergyDefault, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[LightEnergyDefault, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[LightEnergyDefault, $EquipConfigIndex++] = "GrenadeLauncher";
$AIEquipmentSet[LightEnergyDefault, $EquipConfigIndex++] = "GrenadeLauncherAmmo";
$AIEquipmentSet[LightEnergyDefault, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[LightEnergyDefault, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[LightEnergyDefault, $EquipConfigIndex++] = "FlareGrenade";
//$AIEquipmentSet[LightEnergyDefault, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[LightEnergySniper, $EquipConfigIndex++] = "Sniper";
$AIEquipmentSet[LightEnergySniper, $EquipConfigIndex++] = "EnergyPack";
$AIEquipmentSet[LightEnergySniper, $EquipConfigIndex++] = "SlugRifle";
$AIEquipmentSet[LightEnergySniper, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[LightEnergySniper, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[LightEnergySniper, $EquipConfigIndex++] = "HeadHunter";
$AIEquipmentSet[LightEnergySniper, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[LightEnergySniper, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[LightEnergySniper, $EquipConfigIndex++] = "FlareGrenade";
$AIEquipmentSet[LightEnergySniper, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[LightEnergyELF, $EquipConfigIndex++] = "Light";
$AIEquipmentSet[LightEnergyELF, $EquipConfigIndex++] = "EnergyPack";
$AIEquipmentSet[LightEnergyELF, $EquipConfigIndex++] = "ELFGun";
$AIEquipmentSet[LightEnergyELF, $EquipConfigIndex++] = "Chaingun";
$AIEquipmentSet[LightEnergyELF, $EquipConfigIndex++] = "ChaingunAmmo";
$AIEquipmentSet[LightEnergyELF, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[LightEnergyELF, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[LightEnergyELF, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[LightEnergyELF, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[LightEnergyELF, $EquipConfigIndex++] = "ConcussionGrenade";
//$AIEquipmentSet[LightEnergyELF, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[LightShieldSet, $EquipConfigIndex++] = "Light";
$AIEquipmentSet[LightShieldSet, $EquipConfigIndex++] = "ShieldPack";
$AIEquipmentSet[LightShieldSet, $EquipConfigIndex++] = "Shotgun";
$AIEquipmentSet[LightShieldSet, $EquipConfigIndex++] = "ShotgunAmmo";
$AIEquipmentSet[LightShieldSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[LightShieldSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[LightShieldSet, $EquipConfigIndex++] = "GrenadeLauncher";
$AIEquipmentSet[LightShieldSet, $EquipConfigIndex++] = "GrenadeLauncherAmmo";
$AIEquipmentSet[LightShieldSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[LightShieldSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[LightShieldSet, $EquipConfigIndex++] = "FlareGrenade";
//$AIEquipmentSet[LightShieldSet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[LightCloakSet, $EquipConfigIndex++] = "Light";
$AIEquipmentSet[LightCloakSet, $EquipConfigIndex++] = "CloakingPack";
$AIEquipmentSet[LightCloakSet, $EquipConfigIndex++] = "Shotgun";
$AIEquipmentSet[LightCloakSet, $EquipConfigIndex++] = "ShotgunAmmo";
$AIEquipmentSet[LightCloakSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[LightCloakSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[LightCloakSet, $EquipConfigIndex++] = "ShockLance";
$AIEquipmentSet[LightCloakSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[LightCloakSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[LightCloakSet, $EquipConfigIndex++] = "FlashGrenade";
$AIEquipmentSet[LightCloakSet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[LightRepairSet, $EquipConfigIndex++] = "Light";
$AIEquipmentSet[LightRepairSet, $EquipConfigIndex++] = "RepairPack";
$AIEquipmentSet[LightRepairSet, $EquipConfigIndex++] = "Shotgun";
$AIEquipmentSet[LightRepairSet, $EquipConfigIndex++] = "ShotgunAmmo";
$AIEquipmentSet[LightRepairSet, $EquipConfigIndex++] = "Chaingun";
$AIEquipmentSet[LightRepairSet, $EquipConfigIndex++] = "ChaingunAmmo";
$AIEquipmentSet[LightRepairSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[LightRepairSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[LightRepairSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[LightRepairSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[LightRepairSet, $EquipConfigIndex++] = "Grenade";
//$AIEquipmentSet[LightRepairSet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[LightSniperChain, $EquipConfigIndex++] = "Light";
$AIEquipmentSet[LightSniperChain, $EquipConfigIndex++] = "EnergyPack";
$AIEquipmentSet[LightSniperChain, $EquipConfigIndex++] = "HeadHunter";
$AIEquipmentSet[LightSniperChain, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[LightSniperChain, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[LightSniperChain, $EquipConfigIndex++] = "Chaingun";
$AIEquipmentSet[LightSniperChain, $EquipConfigIndex++] = "ChaingunAmmo";
$AIEquipmentSet[LightSniperChain, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[LightSniperChain, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[LightSniperChain, $EquipConfigIndex++] = "FlareGrenade";
$AIEquipmentSet[LightSniperChain, $EquipConfigIndex++] = "Mine";

//new set - Lagg...
$EquipConfigIndex = -1;
$AIEquipmentSet[LightCameraSet, $EquipConfigIndex++] = "Light";
$AIEquipmentSet[LightCameraSet, $EquipConfigIndex++] = "MotionSensorDeployable";
//$AIEquipmentSet[LightCameraSet, $EquipConfigIndex++] = "BeamSword";
$AIEquipmentSet[LightCameraSet, $EquipConfigIndex++] = "Shotgun";
$AIEquipmentSet[LightCameraSet, $EquipConfigIndex++] = "ShotgunAmmo";
$AIEquipmentSet[LightCameraSet, $EquipConfigIndex++] = "ShockLance";
$AIEquipmentSet[LightCameraSet, $EquipConfigIndex++] = "Chaingun";
$AIEquipmentSet[LightCameraSet, $EquipConfigIndex++] = "ChaingunAmmo";
$AIEquipmentSet[LightCameraSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[LightCameraSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[LightCameraSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[LightCameraSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[LightCameraSet, $EquipConfigIndex++] = "CameraGrenade";
//$AIEquipmentSet[LightCameraSet, $EquipConfigIndex++] = "Mine";

//new set - Lagg...
$EquipConfigIndex = -1;
$AIEquipmentSet[LightSensorJammer, $EquipConfigIndex++] = "Light";
$AIEquipmentSet[LightSensorJammer, $EquipConfigIndex++] = "SensorJammerPack";
//$AIEquipmentSet[LightSensorJammer, $EquipConfigIndex++] = "BeamSword";
$AIEquipmentSet[LightSensorJammer, $EquipConfigIndex++] = "Shotgun";
$AIEquipmentSet[LightSensorJammer, $EquipConfigIndex++] = "ShotgunAmmo";
$AIEquipmentSet[LightSensorJammer, $EquipConfigIndex++] = "Chaingun";
$AIEquipmentSet[LightSensorJammer, $EquipConfigIndex++] = "ChaingunAmmo";
$AIEquipmentSet[LightSensorJammer, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[LightSensorJammer, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[LightSensorJammer, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[LightSensorJammer, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[LightSensorJammer, $EquipConfigIndex++] = "FlareGrenade";
$AIEquipmentSet[LightSensorJammer, $EquipConfigIndex++] = "Mine";

// Triumph specific equipment sets:    - pinkpanther
$EquipConfigIndex = -1;
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "Titan";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "ShieldPack";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "TitanChaingun";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "TitanChaingunAmmo";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "Napalm";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "GatlingGun";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "GatlingGunAmmo";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "AntiAirGun";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "AntiAirGunAmmo";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "ConcussionGrenade";
$AIEquipmentSet[TitanDefenderTriumph, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[HeavyEnergyTriumph, $EquipConfigIndex++] = "Heavy";
$AIEquipmentSet[HeavyEnergyTriumph, $EquipConfigIndex++] = "EnergyPack";
$AIEquipmentSet[HeavyEnergyTriumph, $EquipConfigIndex++] = "SolarCharge";
$AIEquipmentSet[HeavyEnergyTriumph, $EquipConfigIndex++] = "Napalm";
$AIEquipmentSet[HeavyEnergyTriumph, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[HeavyEnergyTriumph, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[HeavyEnergyTriumph, $EquipConfigIndex++] = "GatlingGun";
$AIEquipmentSet[HeavyEnergyTriumph, $EquipConfigIndex++] = "GatlingGunAmmo";
$AIEquipmentSet[HeavyEnergyTriumph, $EquipConfigIndex++] = "Mortar";
$AIEquipmentSet[HeavyEnergyTriumph, $EquipConfigIndex++] = "MortarAmmo";
$AIEquipmentSet[HeavyEnergyTriumph, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[HeavyEnergyTriumph, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[HeavyEnergyTriumph, $EquipConfigIndex++] = "ConcussionGrenade";
$AIEquipmentSet[HeavyEnergyTriumph, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[MediumEnergyTriumph, $EquipConfigIndex++] = "Medium";
$AIEquipmentSet[MediumEnergyTriumph, $EquipConfigIndex++] = "EnergyPack";
$AIEquipmentSet[MediumEnergyTriumph, $EquipConfigIndex++] = "RailNade";
$AIEquipmentSet[MediumEnergyTriumph, $EquipConfigIndex++] = "RailNadeAmmo";
$AIEquipmentSet[MediumEnergyTriumph, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[MediumEnergyTriumph, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[MediumEnergyTriumph, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[MediumEnergyTriumph, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[MediumEnergyTriumph, $EquipConfigIndex++] = "Napalm";
$AIEquipmentSet[MediumEnergyTriumph, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[MediumEnergyTriumph, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[MediumEnergyTriumph, $EquipConfigIndex++] = "ConcussionGrenade";
$AIEquipmentSet[MediumEnergyTriumph, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[MediumSensorJammerTriumph, $EquipConfigIndex++] = "Medium";
$AIEquipmentSet[MediumSensorJammerTriumph, $EquipConfigIndex++] = "SensorJammerPack";
$AIEquipmentSet[MediumSensorJammerTriumph, $EquipConfigIndex++] = "Napalm";
$AIEquipmentSet[MediumSensorJammerTriumph, $EquipConfigIndex++] = "GatlingGun";
$AIEquipmentSet[MediumSensorJammerTriumph, $EquipConfigIndex++] = "GatlingGunAmmo";
$AIEquipmentSet[MediumSensorJammerTriumph, $EquipConfigIndex++] = "Hornet";
$AIEquipmentSet[MediumSensorJammerTriumph, $EquipConfigIndex++] = "HornetAmmo";
$AIEquipmentSet[MediumSensorJammerTriumph, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[MediumSensorJammerTriumph, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[MediumSensorJammerTriumph, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[MediumSensorJammerTriumph, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[MediumSensorJammerTriumph, $EquipConfigIndex++] = "FlashGrenade";
$AIEquipmentSet[MediumSensorJammerTriumph, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[ReconAntiEnergy, $EquipConfigIndex++] = "Recon";
$AIEquipmentSet[ReconAntiEnergy, $EquipConfigIndex++] = "AntiEnergyPack";
$AIEquipmentSet[ReconAntiEnergy, $EquipConfigIndex++] = "DualBlaster";
$AIEquipmentSet[ReconAntiEnergy, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[ReconAntiEnergy, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[ReconAntiEnergy, $EquipConfigIndex++] = "FlashGrenade";
$AIEquipmentSet[ReconAntiEnergy, $EquipConfigIndex++] = "Mine";
