// ------------------------------------------------------------------
// DeepCover
//
// When activated, this pack cloaks the user from all visual detection
// by other players and cameras. This is a local effect only (someone standing
// next to the cloaked player will still be visible). Motion sensors will
// still detect a (moving) cloaked player.
//
// When not activated, the pack creates a localized passive sensor dampening
// field.  The user will not be visible to any non-motion-detecting sensor.
//
//Only light armors may equip with this item.

datablock EffectProfile(DeepCoverPackActivateEffect)
{
   effectname = "packs/cloak_on";
   minDistance = 2.5;
   maxDistance = 2.5;
};

datablock AudioProfile(DeepCoverPackActivateSound)
{
   filename = "fx/bonuses/high-level1-frozen.wav";
   description = CloseLooping3d;
   preload = true;
   effect = DeepCoverPackActivateEffect;
};

datablock ShapeBaseImageData(DeepCoverPackImage)
{
   shapeFile = "pack_upgrade_cloaking.dts";
   item = DeepCoverPack;
   mountPoint = 1;
   offset = "0 0 0";

   usesEnergy = true;
   minEnergy = 3;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";
   
   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateSequence[1] = "fire";
   stateSound[1] = DeepCoverPackActivateSound;
   stateEnergyDrain[1] = 8.0;
   stateTransitionOnTriggerUp[1] = "Deactivate";
   stateTransitionOnNoAmmo[1] = "Deactivate";

   stateName[2] = "Deactivate";
   stateScript[2] = "onDeactivate";
   stateTransitionOnTimeout[2] = "Idle";
};

datablock ItemData(DeepCoverPack)
{
   className = Pack;
   catagory = "Packs";
   shapeFile = "pack_upgrade_cloaking.dts";
   mass = 1;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 2;
   rotate = true;
   image = "DeepCoverPackImage";
   pickUpName = "a deep cover pack";

   computeCRC = true;

};

function DeepCoverPackImage::onMount(%data, %obj, %node)
{
   // player is sensor-invisible while wearing pack (except to motion sensors)
   %obj.setPassiveJammed(false);
   Parent::onMount(%this,%obj,%slot);
   CommandToClient(%obj.client, 'CenterPrint', "Deep Cover Pack - when activated, user cloaks without energy drain, but energy wont recharge when active.", 4, 2 );
}

function DeepCoverPackImage::onUnmount(%data, %obj, %node)
{
   %obj.setPassiveJammed(false);
   %obj.setCloaked(false);
   %obj.setImageTrigger(%node, false);
}

// make player completely invisible to all players/sensors (except motion)
function DeepCoverPackImage::onActivate(%data, %obj, %slot)
{
   if(%obj.reCloak !$= "")
   {   
      Cancel(%obj.reCloak);
      %obj.reCloak = "";
   }
   
   if(%obj.client.armor $= "Recon") 
   {
      // can the player currently cloak (function returns "true" or reason for failure)?
      if(%obj.canCloak() $= "true")
      {
         messageClient(%obj.client, 'MsgDeepCoverPackOn', '\c2You are now under deep cover!');
         %obj.setCloaked(true);
         if ( !isDemo() )
            commandToClient( %obj.client, 'setCloakIconOn' );
      }
      else
      {
         // notify player that they cannot cloak
         messageClient(%obj.client, 'MsgDeepCoverPackFailed', '\c2Jamming field prevents Deep Cover ability.');
         %obj.setImageTrigger(%slot, false);
      }
   }
   else 
   {
      // hopefully avoid some loopholes
      messageClient(%obj.client, 'MsgDeepCoverPackInvalid', '\c2Deep Cover available for recon armor only.');
      %obj.setImageTrigger(%slot, false);
   }
}

function DeepCoverPackImage::onDeactivate(%data, %obj, %slot)
{
   if(%obj.reCloak !$= "")
   {   
      Cancel(%obj.reCloak);
      %obj.reCloak = "";
   }
   
   // if pack is not on then dont bother...
   if(%obj.getImageState($BackpackSlot) $= "activate")
      messageClient(%obj.client, 'MsgDeepCoverPackOff', '\c2Deep Cover pack off.');

   %obj.setCloaked(false);
   %obj.setImageTrigger(%slot, false);
   if ( !isDemo() )
      commandToClient( %obj.client, 'setCloakIconOff' );
}

function DeepCoverPack::onPickup(%this, %obj, %shape, %amount)
{
   // created to prevent console errors
}

function ShapeBaseData::onForceUncloak(%this, %obj, %reason)
{
   // dummy
}

function Armor::onForceUncloak(%this, %obj, %reason)
{
   %pack = %obj.getMountedImage($BackpackSlot);
   if((%pack <= 0) || (%pack.item !$= "DeepCoverPack"))
      return;
   
   if(%obj.getImageState($BackpackSlot) $= "activate")
   {
      // cancel recloak thread
      if(%obj.reCloak !$= "")
      {   
         Cancel(%obj.reCloak);
         %obj.reCloak = "";
      }

      messageClient(%obj.client, 'MsgDeepCoverPackOff', '\c2Deep Cover pack off.  Jammed.');
      %obj.setCloaked(false);
      %obj.setImageTrigger($BackpackSlot, false);
   }
}