
// ------------------------------------------
// DeployableForceField.cs
// ------------------------------------------

$TeamDeployableMax[ForceFieldDeployable] = 10;

//crescent

datablock ParticleData( FieldCrescentParticle )
{
   dragCoefficient      = 2;
   gravityCoefficient   = 0.0;
   inheritedVelFactor   = 0.2;
   constantAcceleration = -0.0;
   lifetimeMS           = 600;
   lifetimeVarianceMS   = 000;
   textureName          = "special/crescent3";
   colors[0] = "0.9 0.9 0.9 1.00";
   colors[1] = "0.9 0.9 0.9 0.20";
   colors[2] = "0.9 0.9 0.9 0.0";
   sizes[0]      = 2.0;
   sizes[1]      = 4.0;
   sizes[2]      = 5.0;
   times[0]      = 0.0;
   times[1]      = 0.5;
   times[2]      = 1.0;
};

datablock ParticleEmitterData( FieldCrescentEmitter )
{
   ejectionPeriodMS = 15;
   periodVarianceMS = 0;
   ejectionVelocity = 20;
   velocityVariance = 10.0;
   ejectionOffset   = 0.0;
   thetaMin         = 0;
   thetaMax         = 80;
   phiReferenceVel  = 0;
   phiVariance      = 360;
   overrideAdvances = false;
   orientParticles  = true;
   lifetimeMS       = 200;
   particles = "FieldCrescentParticle";
};

//--------------------------------------------------------------------------
// Shockwave
//--------------------------------------------------------------------------
datablock ShockwaveData(FieldShockwave)
{
   width = 4.0;
   numSegments = 20;
   numVertSegments = 2;
   velocity = 5;
   acceleration = 10.0;
   lifetimeMS = 1000;
   height = 1.0;
   is2D = true;

   texture[0] = "special/shockwave4";
   texture[1] = "special/gradient";
   texWrap = 6.0;

   times[0] = 0.0;
   times[1] = 0.5;
   times[2] = 1.0;

   colors[0] = "0.0 0.1 0.7 1.00";
   colors[1] = "0.0 0.3 0.5 0.5";
   colors[2] = "0.0 0.0 0.2 0.0";
};

//--------------------------------------------------------------------------
// Explosion
//--------------------------------------------------------------------------
datablock ExplosionData(FieldExplosion)
{
   soundProfile   = underwaterDiscExpSound;
   shockwave =  FieldShockwave;

   emitter[0] = FieldCrescentEmitter;

   shakeCamera = true;
   camShakeFreq = "4.0 5.0 4.5";
   camShakeAmp = "140.0 140.0 140.0";
   camShakeDuration = 1.0;
   camShakeRadius = 15.0;
};
datablock StaticShapeData(DeployedForceField) : StaticShapeDamageProfile
{
   className = ForceField;
   shapeFile = "turret_muzzlepoint.dts";
   maxDamage = 4.5;//was20v2.0-RED
   destroyedLevel = 4.5;
   disabledLevel = 4.5;
   explosion = FieldExplosion;
   expDmgRadius = 1.0;
   expDamage = 0.1;
   expImpulse = 2000.0;
   dynamicType = $TypeMasks::StaticShapeObjectType;
   deployedObject = true;
   cmdCategory = "DSupport";
   cmdIcon = CMDSensorIcon;
   cmdMiniIconName = "commander/MiniIcons/com_deploymotionsensor";
   targetNameTag = 'Force';
   targetTypeTag = 'Field';
   deployAmbientThread = true;
   heatSignature = 0;
};

datablock ForceFieldBareData(DeployedForceField2) : StaticShapeDamageProfile
{
   fadeMS = 1000;
   baseTranslucency = 0.5;
   powerOffTranslucency = 0.0;
   teamPermiable = true;
   otherPermiable = false;
   color            = "0.0 0.1 0.7";
   powerOffColor    = "0.0 0.0 0.0";
   targetTypeTag = 'ForceField';

   texture[0] = "skins/forcef1";
   texture[1] = "skins/forcef2";
   texture[2] = "skins/forcef3";
   texture[3] = "skins/forcef4";
   texture[4] = "skins/forcef5";
   framesPerSec = 1;
   numFrames = 1;
   scrollSpeed = 1;
   umapping = 1.0;
   vmapping = 0.15;
   deployedFrom = ForceFieldDeployable;
};

datablock ShapeBaseImageData(ForceFieldDeployableImage)
{
   mass = 20;
   emap = true;
   shapeFile = "Stackable1s.dts";
   item = ForceFieldDeployable;
   mountPoint = 1;
   offset = "0 0 0";
   deployed = DeployedForceField;
   heatSignature = 0;

   stateName[0] = "Idle";
   stateTransitionOnTriggerDown[0] = "Activate";

   stateName[1] = "Activate";
   stateScript[1] = "onActivate";
   stateTransitionOnTriggerUp[1] = "Idle";

   isLarge = true;
   maxDepSlope = 360; // 30
   deploySound = ItemPickupSound;

   minDeployDis = 0.5;
   maxDeployDis = 5.0;
};

datablock ItemData(ForceFieldDeployable)
{
   className = Pack;
   catagory = "Deployables";
   shapeFile = "Stackable1s.dts";
   mass = 5.0;
   elasticity = 0.2;
   friction = 0.6;
   pickupRadius = 1;
   rotate = true;
   image = "ForceFieldDeployableImage";
   pickUpName = "a force field";
   heatSignature = 0;
   emap = true;
};

function ForceFieldDeployable::onPickup(%this, %obj, %shape, %amount)
{
   // created to prevent console errors
}

function DeployedForceField::onDestroyed(%this, %obj, %prevState)
{
   $TeamDeployedCount[%obj.team, ForceFieldDeployable]--;
   %obj.field.pzone.schedule(480, "delete");
   %obj.field.schedule(490, "delete");
   %obj.schedule(500, "delete");
}

function ForceFieldDeployableImage::onDeploy(%item, %plyr, %slot)
{
   %mask = $TypeMasks::InteriorObjectType | $TypeMasks::PlayerObjectType | $TypeMasks::VehicleObjectType;
   %vec = %plyr.getEyeVector();
   %deplObj = Parent::onDeploy(%item, %plyr, %slot);
   %x1 = getWord(%vec, 0);
   %y1 = getWord(%vec, 1);
   %z1 = getWord(%vec, 2);
   %endpos =  VectorAdd(%item.surfacePt, "0 0 10");
   %res = containerRayCast(%item.surfacePt, %endpos, %mask, 0);
   if(%res)
      %zscale=VectorDist("0 0 " @ getword(%res,3),"0 0 " @ getword(%item.SurfacePt,2));
   else
      %zscale=10;
   %extra = %x1;
   %x2 = %y1;
   %y2 = %extra;
   %vec2 = %x2 * -1 SPC %y2 SPC 0;
   %vec3 = %x2 SPC %y2 * -1 SPC 0;
   %initpos = VectorAdd(%item.SurfacePt, "0 0 " @ (%zscale / 2.4));
   %endpos =  VectorAdd(%initpos, VectorScale(%vec2, 10));
   %res = containerRayCast(%initpos, %endpos, %mask, 0);
   if(%res)
      %left=VectorDist(getword(%res,1) SPC getword(%res,2) @ " 0", getword(%item.SurfacePt, 0) SPC getword(%item.SurfacePt, 1) @ " 0");
   else
      %left=10;
   %endpos =  VectorAdd(%initpos, VectorScale(%vec3, 10));
   %res = containerRayCast(%initpos, %endpos, %mask, 0);
   if(%res)
      %right=VectorDist(getword(%res,1) SPC getword(%res,2) @ " 0", getword(%item.SurfacePt, 0) SPC getword(%item.SurfacePt, 1) @ " 0");
   else
      %right=10;
   %wid = %left + %right + 0.2;
   %av = %wid * 2 / 3;
   %movepos = VectorAdd(%item.SurfacePt, VectorScale(%vec2, (%left * 1.4)));
   %centerpos = VectorAdd(%movepos, VectorScale(%vec3, %av));
   %centerpos = VectorAdd(%centerpos, "0 0 " @ (%zscale / 2));
   if ((%x1 > 0) && (%y1 >= 0))
   {
      %zone = 0;
      %rad = mAtan(%x1, %y1);
   }
   else if((%x1 >= 0) && (%y1 < 0))
   {
      %zone = 1;
      %y1 *= -1;
      %rad = mAtan(%y1, %x1);
   }
   else if((%x1 < 0) && (%y1 <= 0))
   {
      %zone = 2;
      %y1 *= -1;
      %x1 *= -1;
      %rad = mAtan(%x1, %y1);
   }
   else if((%x1 <= 0) && (%y1 > 0))
   {
      %zone = 3;
      %x1 *= -1;
      %rad = mAtan(%y1, %x1);
   }
   %angle = mRadtoDeg(%rad);
   if (%zone == 1)
      %angle += 90;
   else if (%zone == 2)
      %angle += 180;
   else if (%zone == 3)
      %angle += 270;

   %rot = " 0 0 1 " @ %angle;
   %pos = getWords(%deplObj.getTransform(), 0, 2);
   %deplObj.field = new ForceFieldBare()
   {
      position = %movepos;
      rotation = %rot;
      scale = %wid @ " 0.02 " @ %zscale;
      dataBlock = "DeployedForceField2";
      parent = %deplObj;
      team = %plyr.team;
   };
   %deplObj.field.active = true;
   %deplObj.field.setSelfPowered();
   MissionCleanup.add(%deplObj.field);
   %deplObj.setTransform(%centerpos);
   %deplObj.team = %plyr.client.team;
   %deplObj.field.team = %plyr.client.team;
   %deplObj.owner = %plyr.client;
   %deplObj.field.owner = %plyr.client;
   %deplObj.field.pzone.team = %plyr.client.Team;
   if(%deplObj.field.getTarget() != -1)
      setTargetSensorGroup(%deplObj.field.getTarget(), %plyr.client.team);
   %deplObj.zscale = %zscale / 2;
}

function DeployedForceField2::onAdd(%data, %obj)
{
   Parent::onAdd(%data, %obj);
   for (%i=0; %i < PZones.getCount(); %i++)
   {
      if (PZones.getObject(%i).ffield == %obj)
         %obj.pzone = PZones.getObject(%i);
   }
}

function DeployedForceField2::damageObject(%data, %targetObject, %sourceObject, %position, %amount, %damageType)
{
   %targetObject.parent.getDataBlock().damageObject(%targetObject.parent, %sourceObject, %position, %amount, %damageType);
}

function ForceFieldBare::isMounted()
{

}


